@@ -363,10 +363,10 @@ class _GeneralConstraintData(_ConstraintData):
                     arg1 = as_numeric(arg1)
 
                 self._equality = True
-                if arg1 is None or arg1.is_fixed():
+                if arg1 is None or (not arg1._potentially_variable()):
                     self._lower = self._upper = arg1
                     self._body = arg0
-                elif arg0 is None or arg0.is_fixed():
+                elif arg0 is None or (not arg0._potentially_variable()):
                     self._lower = self._upper = arg0
                     self._body = arg1
                 else:
@@ -379,12 +379,13 @@ class _GeneralConstraintData(_ConstraintData):
                 arg0 = expr[0]
                 if arg0 is not None:
                     arg0 = as_numeric(arg0)
-                    if not arg0.is_fixed():
+                    if arg0._potentially_variable():
                         raise ValueError(
                             "Constraint '%s' found a 3-tuple (lower,"
                             " expression, upper) but the lower "
-                            "value was non-constant."
-                            % (self.cname(True)))
+                            "value was not data or an expression "
+                            "restricted to storage of data."
+                            % (self.name))
 
                 arg1 = expr[1]
                 if arg1 is not None:
@@ -393,12 +394,13 @@ class _GeneralConstraintData(_ConstraintData):
                 arg2 = expr[2]
                 if arg2 is not None:
                     arg2 = as_numeric(arg2)
-                    if not arg2.is_fixed():
+                    if arg2._potentially_variable():
                         raise ValueError(
                             "Constraint '%s' found a 3-tuple (lower,"
                             " expression, upper) but the upper "
-                            "value was non-constant."
-                            % (self.cname(True)))
+                            "value was not data or an expression "
+                            "restricted to storage of data."
+                            % (self.name))
 
                 self._lower = arg0
                 self._body  = arg1
@@ -410,7 +412,7 @@ class _GeneralConstraintData(_ConstraintData):
                     "length 2 or 3:\n"
                     "Equality:   (left, right)\n"
                     "Inequality: (lower, expression, upper)"
-                    % (self.cname(True), len(expr)))
+                    % (self.name, len(expr)))
 
             relational_expr = False
         else:
@@ -423,14 +425,14 @@ class _GeneralConstraintData(_ConstraintData):
                         "equation. Examples:"
                         "\n   summation(model.costs) == model.income"
                         "\n   (0, model.price[item], 50)"
-                        % (self.cname(True), str(expr)))
+                        % (self.name, str(expr)))
             except AttributeError:
                 msg = ("Constraint '%s' does not have a proper "
                        "value. Found '%s'\nExpecting a tuple or "
                        "equation. Examples:"
                        "\n   summation(model.costs) == model.income"
                        "\n   (0, model.price[item], 50)"
-                       % (self.cname(True), str(expr)))
+                       % (self.name, str(expr)))
                 if type(expr) is bool:
                     msg += ("\nNote: constant Boolean expressions "
                             "are not valid constraint expressions. "
@@ -464,10 +466,10 @@ class _GeneralConstraintData(_ConstraintData):
                     _args = (expr._lhs, expr._rhs)
                 except AttributeError:
                     _args = expr._args
-                if _args[1].is_fixed():
+                if not _args[1]._potentially_variable():
                     self._lower = self._upper = _args[1]
                     self._body = _args[0]
-                elif _args[0].is_fixed():
+                elif not _args[0]._potentially_variable():
                     self._lower = self._upper = _args[0]
                     self._body = _args[1]
                 else:
@@ -502,7 +504,7 @@ class _GeneralConstraintData(_ConstraintData):
                             "inequality expression ('>' or '<'). All"
                             " constraints must be formulated using "
                             "using '<=', '>=', or '=='."
-                            % (self.cname(True)))
+                            % (self.name))
 
                 try:
                     _args = (expr._lhs, expr._rhs)
@@ -521,20 +523,22 @@ class _GeneralConstraintData(_ConstraintData):
 
                 if len(_args) == 3:
 
-                    if not _args[0].is_fixed():
+                    if _args[0]._potentially_variable():
                         raise ValueError(
                             "Constraint '%s' found a double-sided "
                             "inequality expression (lower <= "
                             "expression <= upper) but the lower "
-                            "bound was non-constant."
-                            % (self.cname(True)))
-                    if not _args[2].is_fixed():
+                            "bound was not data or an expression "
+                            "restricted to storage of data."
+                            % (self.name))
+                    if _args[2]._potentially_variable():
                         raise ValueError(
                             "Constraint '%s' found a double-sided "\
                             "inequality expression (lower <= "
                             "expression <= upper) but the upper "
-                            "bound was non-constant."
-                            % (self.cname(True)))
+                            "bound was not data or an expression "
+                            "restricted to storage of data."
+                            % (self.name))
 
                     self._lower = _args[0]
                     self._body  = _args[1]
@@ -542,11 +546,11 @@ class _GeneralConstraintData(_ConstraintData):
 
                 else:
 
-                    if _args[1].is_fixed():
+                    if not _args[1]._potentially_variable():
                         self._lower = None
                         self._body  = _args[0]
                         self._upper = _args[1]
-                    elif _args[0].is_fixed():
+                    elif not _args[0]._potentially_variable():
                         self._lower = _args[0]
                         self._body  = _args[1]
                         self._upper = None
@@ -571,12 +575,12 @@ class _GeneralConstraintData(_ConstraintData):
                 if val > 0:
                     raise ValueError(
                         "Constraint '%s' created with a +Inf lower "
-                        "bound." % (self.cname(True)))
+                        "bound." % (self.name))
                 self._lower = None
             elif bool(val > 0) == bool(val <= 0):
                 raise ValueError(
                     "Constraint '%s' created with a non-numeric "
-                    "lower bound." % (self.cname(True)))
+                    "lower bound." % (self.name))
 
         if (self._upper is not None) and \
            is_constant(self._upper):
@@ -585,12 +589,12 @@ class _GeneralConstraintData(_ConstraintData):
                 if val < 0:
                     raise ValueError(
                         "Constraint '%s' created with a -Inf upper "
-                        "bound." % (self.cname(True)))
+                        "bound." % (self.name))
                 self._upper = None
             elif bool(val > 0) == bool(val <= 0):
                 raise ValueError(
                     "Constraint '%s' created with a non-numeric "
-                    "upper bound." % (self.cname(True)))
+                    "upper bound." % (self.name))
 
         #
         # Error check, to ensure that we don't have a constraint that
@@ -603,7 +607,7 @@ class _GeneralConstraintData(_ConstraintData):
             if self._lower is None:
                 raise ValueError(
                     "Equality constraint '%s' defined with "
-                    "non-finite term." % (self.cname(True)))
+                    "non-finite term." % (self.name))
             assert self._lower is self._upper
 
 class Constraint(ActiveIndexedComponent):
@@ -647,7 +651,7 @@ class Constraint(ActiveIndexedComponent):
     def __new__(cls, *args, **kwds):
         if cls != Constraint:
             return super(Constraint, cls).__new__(cls)
-        if args == () or (args[0] == UnindexedComponent_set and len(args)==1):
+        if args == () or (type(args[0]) == set and args[0] == UnindexedComponent_set and len(args)==1):
             return SimpleConstraint.__new__(SimpleConstraint)
         else:
             return IndexedConstraint.__new__(IndexedConstraint)
@@ -667,7 +671,7 @@ class Constraint(ActiveIndexedComponent):
         """
         if __debug__ and logger.isEnabledFor(logging.DEBUG):
             logger.debug("Constructing constraint %s"
-                         % (self.cname(True)))
+                         % (self.name))
         if self._constructed:
             return
         self._constructed=True
@@ -701,13 +705,13 @@ class Constraint(ActiveIndexedComponent):
                     logger.error(
                         "Rule failed when generating expression for "
                         "constraint %s:\n%s: %s"
-                        % (self.cname(True),
+                        % (self.name,
                            type(err).__name__,
                            err))
                     raise
                 if tmp is None:
                     raise ValueError(
-                        _rule_returned_none_error % (self.cname(True),) )
+                        _rule_returned_none_error % (self.name,) )
 
             assert None not in self._data
             cdata = self._check_skip_add(None, tmp, condata=self)
@@ -725,8 +729,8 @@ class Constraint(ActiveIndexedComponent):
             if not _init_expr is None:
                 raise IndexError(
                     "Constraint '%s': Cannot initialize multiple indices "
-                    "of a constraint with a single expression" % 
-                    (self.cname(True),) )
+                    "of a constraint with a single expression" %
+                    (self.name,) )
 
             for ndx in self._index:
                 try:
@@ -739,15 +743,15 @@ class Constraint(ActiveIndexedComponent):
                     logger.error(
                         "Rule failed when generating expression for "
                         "constraint %s with index %s:\n%s: %s"
-                        % (self.cname(True),
+                        % (self.name,
                            str(ndx),
                            type(err).__name__,
                            err))
                     raise
                 if tmp is None:
                     raise ValueError(
-                        _rule_returned_none_error % 
-                        ('%s[%s]' % (self.cname(True), str(ndx)),) )
+                        _rule_returned_none_error %
+                        ('%s[%s]' % (self.name, str(ndx)),) )
 
                 cdata = self._check_skip_add(ndx, tmp)
                 if cdata is not None:
@@ -764,9 +768,8 @@ class Constraint(ActiveIndexedComponent):
              ("Active", self.active),
              ],
             iteritems(self),
-            ( "Key","Lower","Body","Upper","Active" ),
-            lambda k, v: [ k,
-                           "-Inf" if v.lower is None else v.lower,
+            ( "Lower","Body","Upper","Active" ),
+            lambda k, v: [ "-Inf" if v.lower is None else v.lower,
                            v.body,
                            "+Inf" if v.upper is None else v.upper,
                            v.active,
@@ -784,15 +787,14 @@ class Constraint(ActiveIndexedComponent):
         if ostream is None:
             ostream = sys.stdout
         tab="    "
-        ostream.write(prefix+self.cname()+" : ")
+        ostream.write(prefix+self.local_name+" : ")
         ostream.write("Size="+str(len(self)))
 
         ostream.write("\n")
         tabular_writer( ostream, prefix+tab,
                         ((k,v) for k,v in iteritems(self._data) if v.active),
-                        ( "Key","Lower","Body","Upper" ),
-                        lambda k, v: [ k,
-                                       value(v.lower),
+                        ( "Lower","Body","Upper" ),
+                        lambda k, v: [ value(v.lower),
                                        v.body(),
                                        value(v.upper),
                                        ] )
@@ -834,7 +836,7 @@ class Constraint(ActiveIndexedComponent):
                     "object. Please modify your rule to return "
                     "Constraint.Skip instead of None."
                     "\n\nError thrown for Constraint '%s'"
-                    % (self._data[index].cname(True)))
+                    % (self._data[index].name))
 
             #
             # There are cases where a user thinks they are generating
@@ -868,7 +870,7 @@ class Constraint(ActiveIndexedComponent):
                     "\n\nError thrown for Constraint '%s'"
                     "\n\nUnresolved (dangling) inequality "
                     "expression: %s"
-                    % (expr, self._data[index].cname(True), buf))
+                    % (expr, self._data[index].name, buf))
             else:
                 raise ValueError(
                     "Invalid constraint expression. The constraint "
@@ -879,7 +881,7 @@ class Constraint(ActiveIndexedComponent):
                     % (expr,
                        expr and "Feasible" or "Infeasible",
                        expr,
-                       self._data[index].cname(True)))
+                       self._data[index].name))
 
         #
         # Ignore an 'empty' constraint
@@ -892,7 +894,7 @@ class Constraint(ActiveIndexedComponent):
                 _prep_for_error()
                 raise ValueError(
                     "Constraint '%s' is always infeasible"
-                    % self._data[index].cname(True))
+                    % self._data[index].name)
 
         if condata is None:
             self._data[index] = condata = \
@@ -938,13 +940,13 @@ class SimpleConstraint(_GeneralConstraintData, Constraint):
                     "Accessing the body of SimpleConstraint "
                     "'%s' before the Constraint has been assigned "
                     "an expression. There is currently "
-                    "nothing to access." % (self.cname(True)))
+                    "nothing to access." % (self.name))
             return _GeneralConstraintData.body.fget(self)
         raise ValueError(
             "Accessing the body of constraint '%s' "
             "before the Constraint has been constructed (there "
             "is currently no value to return)."
-            % (self.cname(True)))
+            % (self.name))
 
     @property
     def lower(self):
@@ -955,13 +957,13 @@ class SimpleConstraint(_GeneralConstraintData, Constraint):
                     "Accessing the lower bound of SimpleConstraint "
                     "'%s' before the Constraint has been assigned "
                     "an expression. There is currently "
-                    "nothing to access." % (self.cname(True)))
+                    "nothing to access." % (self.name))
             return _GeneralConstraintData.lower.fget(self)
         raise ValueError(
             "Accessing the lower bound of constraint '%s' "
             "before the Constraint has been constructed (there "
             "is currently no value to return)."
-            % (self.cname(True)))
+            % (self.name))
 
     @property
     def upper(self):
@@ -972,13 +974,13 @@ class SimpleConstraint(_GeneralConstraintData, Constraint):
                     "Accessing the upper bound of SimpleConstraint "
                     "'%s' before the Constraint has been assigned "
                     "an expression. There is currently "
-                    "nothing to access." % (self.cname(True)))
+                    "nothing to access." % (self.name))
             return _GeneralConstraintData.upper.fget(self)
         raise ValueError(
             "Accessing the upper bound of constraint '%s' "
             "before the Constraint has been constructed (there "
             "is currently no value to return)."
-            % (self.cname(True)))
+            % (self.name))
 
     @property
     def equality(self):
@@ -989,13 +991,13 @@ class SimpleConstraint(_GeneralConstraintData, Constraint):
                     "Accessing the equality flag of SimpleConstraint "
                     "'%s' before the Constraint has been assigned "
                     "an expression. There is currently "
-                    "nothing to access." % (self.cname(True)))
+                    "nothing to access." % (self.name))
             return _GeneralConstraintData.equality.fget(self)
         raise ValueError(
             "Accessing the equality flag of constraint '%s' "
             "before the Constraint has been constructed (there "
             "is currently no value to return)."
-            % (self.cname(True)))
+            % (self.name))
 
     @property
     def strict_lower(self):
@@ -1006,13 +1008,13 @@ class SimpleConstraint(_GeneralConstraintData, Constraint):
                     "Accessing the strict_lower flag of SimpleConstraint "
                     "'%s' before the Constraint has been assigned "
                     "an expression. There is currently "
-                    "nothing to access." % (self.cname(True)))
+                    "nothing to access." % (self.name))
             return _GeneralConstraintData.strict_lower.fget(self)
         raise ValueError(
             "Accessing the strict_lower flag of constraint '%s' "
             "before the Constraint has been constructed (there "
             "is currently no value to return)."
-            % (self.cname(True)))
+            % (self.name))
 
     @property
     def strict_upper(self):
@@ -1023,13 +1025,13 @@ class SimpleConstraint(_GeneralConstraintData, Constraint):
                     "Accessing the strict_upper flag of SimpleConstraint "
                     "'%s' before the Constraint has been assigned "
                     "an expression. There is currently "
-                    "nothing to access." % (self.cname(True)))
+                    "nothing to access." % (self.name))
             return _GeneralConstraintData.strict_upper.fget(self)
         raise ValueError(
             "Accessing the strict_upper flag of constraint '%s' "
             "before the Constraint has been constructed (there "
             "is currently no value to return)."
-            % (self.cname(True)))
+            % (self.name))
 
     #
     # Singleton constraints are strange in that we want them to be
@@ -1052,7 +1054,7 @@ class SimpleConstraint(_GeneralConstraintData, Constraint):
             "Setting the value of constraint '%s' "
             "before the Constraint has been constructed (there "
             "is currently no object to set)."
-            % (self.cname(True)))
+            % (self.name))
 
     #
     # Leaving this method for backward compatibility reasons.
@@ -1064,7 +1066,7 @@ class SimpleConstraint(_GeneralConstraintData, Constraint):
             raise ValueError(
                 "SimpleConstraint object '%s' does not accept "
                 "index values other than None. Invalid value: %s"
-                % (self.cname(True), index))
+                % (self.name, index))
         self.set_value(expr)
         return self
 
@@ -1114,7 +1116,7 @@ class ConstraintList(IndexedConstraint):
             __debug__ and logger.isEnabledFor(logging.DEBUG)
         if generate_debug_messages:
             logger.debug("Constructing constraint list %s"
-                         % (self.cname(True)))
+                         % (self.name))
 
         if self._constructed:
             return
@@ -1152,7 +1154,7 @@ class ConstraintList(IndexedConstraint):
                 if expr is None:
                     raise ValueError(
                         "ConstraintList '%s': rule returned None "
-                        "instead of ConstraintList.End" % (self.cname(True),) )
+                        "instead of ConstraintList.End" % (self.name,) )
                 if (expr.__class__ is tuple) and \
                    (expr == ConstraintList.End):
                     return
@@ -1164,7 +1166,7 @@ class ConstraintList(IndexedConstraint):
                 if expr is None:
                     raise ValueError(
                         "ConstraintList '%s': generator returned None "
-                        "instead of ConstraintList.End" % (self.cname(True),) )
+                        "instead of ConstraintList.End" % (self.name,) )
                 if (expr.__class__ is tuple) and \
                    (expr == ConstraintList.End):
                     return
