@@ -13,10 +13,10 @@ from __future__ import division
 #            'asin', 'acos', 'atan', 'exp', 'sqrt', 'asinh', 'acosh',
 #            'atanh', 'ceil', 'floor' )
 
-import copy
 import logging
 import math
 import sys
+import traceback
 
 logger = logging.getLogger('pyomo.core')
 
@@ -42,72 +42,60 @@ except:
 from pyomo.core.base.component import Component
 #from pyomo.core.base.plugin import *
 from pyomo.core.base.numvalue import *
-from pyomo.core.base.numvalue import ZeroConstant, native_numeric_types
-from pyomo.core.base.var import _VarData
+from pyomo.core.base.numvalue import native_numeric_types, native_types
+from pyomo.core.base.var import _VarData, Var
 
 import pyomo.core.base.expr_common
 from pyomo.core.base.expr_common import \
     _add, _sub, _mul, _div, _pow, _neg, _abs, _inplace, _unary, \
     _radd, _rsub, _rmul, _rdiv, _rpow, _iadd, _isub, _imul, _idiv, _ipow, \
-    _lt, _le, _eq
+    _lt, _le, _eq, clone_expression, chainedInequalityErrorMessage as cIEM
+
+# Wrap the common chainedInequalityErrorMessage to pass the local context
+chainedInequalityErrorMessage \
+    = lambda *x: cIEM(generate_relational_expression, *x)
 
 
-def clone_expression(exp):
-    if exp.is_expression():
-        # It is important that this function calls the clone method not __copy__.
-        # __copy__ and clone are the same for all classes that advertise "is_expression = True"
-        # except the _ExpressionData class (in which case clone does nothing
-        # so that the object remains persistent when generating expressions)
-        return exp.clone()
-    else:
-        return exp
-
-def chainedInequalityErrorMessage(msg=None):
-    if msg is None:
-        msg = "Nonconstant relational expression used in an "\
-              "unexpected Boolean context."
-    buf = StringIO()
-    generate_relational_expression.chainedInequality.to_string(buf)
-    # We are about to raise an exception, so it's OK to reset chainedInequality
-    generate_relational_expression.chainedInequality = None
-    msg += """
-The inequality expression:
-    %s
-contains non-constant terms (variables) appearing in a Boolean context, e.g.:
-    if expression <= 5:
-This is generally invalid.  If you want to obtain the Boolean value of
-the expression based on the current variable values, explicitly evaluate
-the expression, e.g.:
-    if value(expression) <= 5:
-or
-    if value(expression <= 5):
-""" % ( buf.getvalue().strip(), )
-    return msg
-
-
-def identify_variables(expr, include_fixed=True):
-    if expr.is_expression():
-        if type(expr) is _ProductExpression:
-            for arg in expr._numerator:
-                for var in identify_variables(arg, include_fixed):
-                    yield var
-            for arg in expr._denominator:
-                for var in identify_variables(arg, include_fixed):
-                    yield var
-        elif type(expr) is _ExternalFunctionExpression:
-            for arg in expr._args:
-                if isinstance(arg, basestring):
-                    continue
-                for var in identify_variables(arg, include_fixed):
-                    yield var
-        else:
-            for arg in expr._args:
-                for var in identify_variables(arg, include_fixed):
-                    yield var
-    elif include_fixed or not expr.is_fixed():
-        if isinstance(expr, _VarData):
-            yield expr
-
+def identify_variables( expr,
+                        include_fixed=True,
+                        allow_duplicates=False,
+                        include_potentially_variable=False ):
+    if not allow_duplicates:
+        _seen = set()
+    _stack = [ ([expr], 0, 1) ]
+    while _stack:
+        _argList, _idx, _len = _stack.pop()
+        while _idx < _len:
+            _sub = _argList[_idx]
+            _idx += 1
+            if type(_sub) in native_types:
+                pass
+            elif _sub.is_expression():
+                _stack.append(( _argList, _idx, _len ))
+                if type(_sub) is _ProductExpression:
+                    if _sub._denominator:
+                        _stack.append(
+                            (_sub._denominator, 0, len(_sub._denominator)) )
+                    _argList = _sub._numerator
+                else:
+                    _argList = _sub._args
+                _idx = 0
+                _len = len(_argList)
+            elif isinstance(_sub, _VarData):
+                if ( include_fixed
+                     or not _sub.is_fixed()
+                     or include_potentially_variable ):
+                    if not allow_duplicates:
+                        if id(_sub) in _seen:
+                            continue
+                        _seen.add(id(_sub))
+                    yield _sub
+            elif include_potentially_variable and _sub._potentially_variable():
+                if not allow_duplicates:
+                    if id(_sub) in _seen:
+                        continue
+                    _seen.add(id(_sub))
+                yield _sub
 
 class _ExpressionBase(NumericValue):
     """An object that defines a mathematical expression that can be evaluated"""
@@ -131,7 +119,7 @@ class _ExpressionBase(NumericValue):
             ostream = sys.stdout
         _verbose = pyomo.core.base.expr_common.TO_STRING_VERBOSE \
                    if verbose is None else verbose
-        ostream.write(self.cname() + "( ")
+        ostream.write(self.getname() + "( ")
         first = True
         for arg in self._args:
             if first:
@@ -140,17 +128,15 @@ class _ExpressionBase(NumericValue):
                 ostream.write(" , ")
             else:
                 ostream.write(", ")
-            arg.to_string( ostream=ostream, precedence=self._precedence(),
-                           verbose=verbose )
+            try:
+                arg.to_string( ostream=ostream, precedence=self._precedence(),
+                               verbose=verbose )
+            except AttributeError:
+                ostream.write("(%s)" % (arg,))
         ostream.write(" )")
 
-    def clone(self):
-        return copy.copy(self)
-
-    def __copy__(self):
-        """Clone this object using the specified arguments"""
-        raise NotImplementedError("Derived expression (%s) failed to "\
-            "implement __copy__()" % ( str(self.__class__), ))
+    def clone(self, substitute=None):
+        return clone_expression(self, substitute)
 
     def simplify(self, model): #pragma:nocover
         print("""
@@ -182,6 +168,12 @@ WARNING: _ExpressionBase.simplify() has been deprecated and removed from
                 return False
         return True
 
+    def _potentially_variable(self):
+        for arg in self._args:
+            if arg._potentially_variable():
+                return True
+        return False
+
     def is_expression(self):
         return True
 
@@ -214,8 +206,9 @@ WARNING: _ExpressionBase.simplify() has been deprecated and removed from
             except Exception:
                 if exception:
                     e = sys.exc_info()[1]
-                    logger.error("evaluating expression: %s\n    (expression: %s)",
-                                 str(e), str(self))
+                    logger.error(
+                        "evaluating expression: %s\n    (expression: %s)",
+                        str(e), str(self) )
                     raise
                 yield None
 
@@ -231,11 +224,17 @@ WARNING: _ExpressionBase.simplify() has been deprecated and removed from
         return buf.getvalue()
 
 class _ExternalFunctionExpression(_ExpressionBase):
-    __slots__ = ('_fcn')
+    __slots__ = ('_fcn',)
 
     def __init__(self, fcn, args):
         """Construct a call to an external function"""
-        _ExpressionBase.__init__(self, args)
+        _args = tuple(
+            _generate_expression__clone_if_needed(
+                x,-2) if isinstance(x, _ExpressionBase)
+            else x if isinstance(x, basestring)
+            else as_numeric(x)
+            for x in args )
+        _ExpressionBase.__init__(self, _args)
         self._fcn = fcn
 
     def __getstate__(self):
@@ -244,12 +243,8 @@ class _ExternalFunctionExpression(_ExpressionBase):
             result[i] = getattr(self, i)
         return result
 
-    def __copy__(self):
-        return self.__class__( self._fcn,
-                               tuple(clone_expression(x) for x in self._args) )
-
-    def cname(self):
-        return self._fcn.cname()
+    def getname(self, *args, **kwds):
+        return self._fcn.getname(*args, **kwds)
 
     def polynomial_degree(self):
         return None
@@ -270,6 +265,14 @@ class _ExternalFunctionExpression(_ExpressionBase):
                 return False
         return True
 
+    def _potentially_variable(self):
+        for arg in self._args:
+            if isinstance(arg, basestring):
+                continue
+            if arg._potentially_variable():
+                return True
+        return False
+
     def _apply_operation(self, values):
         return self._fcn.evaluate(values)
 
@@ -281,7 +284,7 @@ class _IntrinsicFunctionExpression(_ExpressionBase):
         """Construct an expression with an operation and a set of arguments"""
         if nargs and nargs != len(args):
             raise ValueError("%s() takes exactly %d arguments (%d given)" % \
-                ( self.cname(), nargs, len(args) ))
+                ( self.name, nargs, len(args) ))
         _ExpressionBase.__init__(self, args)
         self._operator = operator
         self._name = name
@@ -292,16 +295,10 @@ class _IntrinsicFunctionExpression(_ExpressionBase):
             result[i] = getattr(self, i)
         return result
 
-    def __copy__(self):
-        return self.__class__( self._name,
-                               None,
-                               tuple(clone_expression(x) for x in self._args),
-                               self._operator )
-
     def _apply_operation(self, values):
         return self._operator(*tuple(values))
 
-    def cname(self):
+    def getname(self, *args, **kwds):
         return self._name
 
     def polynomial_degree(self):
@@ -319,11 +316,8 @@ class _AbsExpression(_IntrinsicFunctionExpression):
     def __init__(self, args):
         _IntrinsicFunctionExpression.__init__(self, 'abs', 1, args, abs)
 
-    def __getstate__(self):
-        return _IntrinsicFunctionExpression.__getstate__(self)
-
-    def __copy__(self):
-        return self.__class__( tuple(clone_expression(x) for x in self._args) )
+    #def __getstate__(self):
+    #    return _IntrinsicFunctionExpression.__getstate__(self)
 
 # Should this actually be a special class, or just an instance of
 # _IntrinsicFunctionExpression (like sin, cos, etc)?
@@ -335,11 +329,8 @@ class _PowExpression(_IntrinsicFunctionExpression):
     def __init__(self, args):
         _IntrinsicFunctionExpression.__init__(self, 'pow', 2, args, pow)
 
-    def __getstate__(self):
-        return _IntrinsicFunctionExpression.__getstate__(self)
-
-    def __copy__(self):
-        return self.__class__( tuple(clone_expression(x) for x in self._args) )
+    #def __getstate__(self):
+    #    return _IntrinsicFunctionExpression.__getstate__(self)
 
     def polynomial_degree(self):
         # _PowExpression is a tricky thing.  In general, a**b is
@@ -371,6 +362,9 @@ class _PowExpression(_IntrinsicFunctionExpression):
             return self._args[0].is_fixed() or bool(self._args[1] == 0)
         return False
 
+    # the base class implementation is fine
+    #def _potentially_variable(self)
+
     def _precedence(self):
         return _PowExpression.PRECEDENCE
 
@@ -395,8 +389,11 @@ class _PowExpression(_IntrinsicFunctionExpression):
                 first = False
             else:
                 ostream.write("**")
-            arg.to_string( ostream=ostream, verbose=verbose,
-                           precedence=self._precedence() )
+            try:
+                arg.to_string( ostream=ostream, verbose=verbose,
+                               precedence=self._precedence() )
+            except AttributeError:
+                ostream.write("(%s)" % (arg,))
         if precedence and _my_precedence > precedence:
             ostream.write(" )")
 
@@ -447,7 +444,9 @@ class _InequalityExpression(_LinearExpression):
     def __nonzero__(self):
         if generate_relational_expression.chainedInequality is not None:
             raise TypeError(chainedInequalityErrorMessage())
-        if not self.is_constant():
+        if not self.is_constant() and len(self._args) == 2:
+            generate_relational_expression.call_info \
+                = traceback.extract_stack(limit=2)[-2]
             generate_relational_expression.chainedInequality = self
             return True
 
@@ -461,11 +460,6 @@ class _InequalityExpression(_LinearExpression):
     def _precedence(self):
         return _InequalityExpression.PRECEDENCE
 
-    def __copy__(self):
-        return self.__class__( [clone_expression(x) for x in self._args],
-                               copy.copy(self._strict),
-                               copy.copy(self._cloned_from) )
-
     def _apply_operation(self, values):
         """Method that defines the less-than-or-equal operation"""
         arg1 = next(values)
@@ -489,15 +483,21 @@ class _InequalityExpression(_LinearExpression):
             ostream.write("( ")
         for i, strict in enumerate(self._strict):
             arg = self._args[i]
-            arg.to_string( ostream=ostream, verbose=verbose,
-                           precedence=_my_precedence )
+            try:
+                arg.to_string( ostream=ostream, verbose=verbose,
+                               precedence=_my_precedence )
+            except AttributeError:
+                ostream.write("(%s)" % (arg,))
             if strict:
                 ostream.write("  <  ")
             else:
                 ostream.write("  <=  ")
         arg = self._args[-1]
-        arg.to_string( ostream=ostream, verbose=verbose,
-                       precedence=_my_precedence )
+        try:
+            arg.to_string( ostream=ostream, verbose=verbose,
+                           precedence=_my_precedence )
+        except AttributeError:
+            ostream.write("(%s)" % (arg,))
         if precedence and _my_precedence > precedence:
             ostream.write(" )")
 
@@ -512,12 +512,9 @@ class _EqualityExpression(_LinearExpression):
         """Constructor"""
         if 2 != len(args):
             raise ValueError("%s() takes exactly 2 arguments (%d given)" % \
-                ( self.cname(), len(args) ))
+                ( self.name, len(args) ))
         _LinearExpression.__init__(self, args)
 
-    def __copy__(self):
-        return self.__class__( tuple(clone_expression(x) for x in self._args) )
-
     def __nonzero__(self):
         if generate_relational_expression.chainedInequality is not None:
             raise TypeError(chainedInequalityErrorMessage())
@@ -548,8 +545,11 @@ class _EqualityExpression(_LinearExpression):
                 first = False
             else:
                 ostream.write("  ==  ")
-            arg.to_string( ostream=ostream, verbose=verbose,
-                           precedence=_my_precedence)
+            try:
+                arg.to_string( ostream=ostream, verbose=verbose,
+                               precedence=_my_precedence)
+            except AttributeError:
+                ostream.write("(%s)" % (arg,))
         if precedence and _my_precedence > precedence:
             ostream.write(" )")
 
@@ -600,6 +600,15 @@ class _ProductExpression(_ExpressionBase):
                 return False
         return True
 
+    def _potentially_variable(self):
+        for arg in self._numerator:
+            if arg._potentially_variable():
+                return True
+        for arg in self._denominator:
+            if arg._potentially_variable():
+                return True
+        return False
+
     def _precedence(self):
         return _ProductExpression.PRECEDENCE
 
@@ -642,8 +651,11 @@ class _ProductExpression(_ExpressionBase):
                 ostream.write(" , ")
             else:
                 ostream.write(" * ")
-            arg.to_string( ostream=ostream, verbose=verbose,
-                           precedence=_my_precedence )
+            try:
+                arg.to_string( ostream=ostream, verbose=verbose,
+                               precedence=_my_precedence )
+            except AttributeError:
+                ostream.write("(%s)" % (arg,))
         if first:
             ostream.write('1')
         if len(self._denominator) > 0:
@@ -661,8 +673,11 @@ class _ProductExpression(_ExpressionBase):
                     ostream.write(" , ")
                 else:
                     ostream.write(" * ")
-                arg.to_string( ostream=ostream, verbose=verbose,
-                               precedence=_my_precedence )
+                try:
+                    arg.to_string( ostream=ostream, verbose=verbose,
+                                   precedence=_my_precedence )
+                except AttributeError:
+                    ostream.write("(%s)" % (arg,))
             if len(self._denominator) > 1 and not _verbose:
                 ostream.write(" )")
         if _verbose:
@@ -670,14 +685,6 @@ class _ProductExpression(_ExpressionBase):
         elif precedence and _my_precedence > precedence:
             ostream.write(" )")
 
-    def __copy__(self):
-        """Clone this object using the specified arguments"""
-        tmp = self.__class__()
-        tmp._numerator = [clone_expression(x) for x in self._numerator]
-        tmp._denominator = [clone_expression(x) for x in self._denominator]
-        tmp._coef = self._coef
-        return tmp
-
     def __call__(self, exception=True):
         """Evaluate the expression"""
         try:
@@ -723,14 +730,6 @@ class _SumExpression(_LinearExpression):
             result[i] = getattr(self, i)
         return result
 
-    def __copy__(self):
-        """Clone this object using the specified arguments"""
-        tmp = self.__class__()
-        tmp._args = [clone_expression(x) for x in self._args]
-        tmp._coef = copy.copy(self._coef)
-        tmp._const = self._const
-        return tmp
-
     def _precedence(self):
         return _SumExpression.PRECEDENCE
 
@@ -778,8 +777,11 @@ class _SumExpression(_LinearExpression):
             else:
                 ostream.write(str(abs(self._coef[i]))+"*")
                 _sub_precedence = _ProductExpression.PRECEDENCE
-            arg.to_string( ostream=ostream, verbose=verbose,
-                           precedence=_sub_precedence )
+            try:
+                arg.to_string( ostream=ostream, verbose=verbose,
+                               precedence=_sub_precedence )
+            except AttributeError:
+                ostream.write("(%s)" % arg)
             first=False
         if _verbose or ( precedence and _my_precedence > precedence ):
             ostream.write(" )")
@@ -813,7 +815,7 @@ class Expr_if(_ExpressionBase):
             result[i] = getattr(self, i)
         return result
 
-    def cname(self):
+    def getname(self, *args, **kwds):
         return "Expr_if"
 
     def is_constant(self):
@@ -834,6 +836,9 @@ class Expr_if(_ExpressionBase):
         else:
             return False
 
+    # the base class implementation is fine
+    #def _potentially_variable(self)
+
     def polynomial_degree(self):
         if self._if.is_fixed():
             if self._if():
@@ -859,12 +864,6 @@ class Expr_if(_ExpressionBase):
                               precedence=self._precedence())
         ostream.write(" ) )")
 
-    def __copy__(self):
-        """Clone this object using the specified arguments"""
-        return self.__class__(IF=clone_expression(self._if),
-                              THEN=clone_expression(self._then),
-                              ELSE=clone_expression(self._else))
-
     def __call__(self, exception=True):
         """Evaluate the expression"""
         if self._if(exception=exception):
@@ -873,6 +872,39 @@ class Expr_if(_ExpressionBase):
             return self._else(exception=exception)
 
 
+class _GetItemExpression(_ExpressionBase):
+    __slots__ = ('_base',)
+
+    def __init__(self, base, args):
+        """Construct a call to an external function"""
+        _ExpressionBase.__init__(self, args)
+        self._base = base
+
+    def __getstate__(self):
+        result = _ExpressionBase.__getstate__(self)
+        for i in _GetItemExpression.__slots__:
+            result[i] = getattr(self, i)
+        return result
+
+    def getname(self, *args, **kwds):
+        return self._base.getname(*args, **kwds)
+
+    def polynomial_degree(self):
+        return 0 if self.is_fixed() else 1
+
+    def is_constant(self):
+        return False
+
+    def is_fixed(self):
+        return not isinstance(self._base, Var)
+
+    def _apply_operation(self, values):
+        return value(self._base[values])
+
+    def resolve_template(self):
+        return self._base.__getitem__(tuple(value(i) for i in self._args))
+
+
 def _generate_expression__clone_if_needed(obj, target):
     #print(getrefcount(obj) - UNREFERENCED_EXPR_COUNT, target)
     if getrefcount(obj) - UNREFERENCED_EXPR_COUNT == target:
@@ -933,7 +965,7 @@ def generate_expression(etype, _self, other):
         raise TypeError("Argument for expression '%s' is an indexed "\
               "numeric value specified without an index: %s\n    Is "\
               "variable or parameter '%s' defined over an index that "\
-              "you did not specify?" % (etype, _self.cname(), _self.cname()))
+              "you did not specify?" % (etype, _self.name, _self.name))
 
     self_type = _self.__class__
     # In-place operators should only clone `self` if someone else (other
@@ -992,7 +1024,7 @@ def generate_expression(etype, _self, other):
                 "Argument for expression '%s' is an indexed numeric "
                 "value\nspecified without an index:\n\t%s\nIs this "
                 "value defined over an index that you did not specify?"
-                % (etype, other.cname(), ) )
+                % (etype, other.name, ) )
         if other.is_expression():
             other = _generate_expression__clone_if_needed(other, 0)
         elif other.is_constant():
@@ -1340,7 +1372,7 @@ def generate_relational_expression(etype, lhs, rhs):
             "specified without an index: %s\n    Is variable or parameter "
             "'%s' defined over an index that you did not specify?"
             % ({_eq:'==',_lt:'<',_le:'<='}.get(etype, etype),
-               lhs.cname(), lhs.cname()))
+               lhs.name, lhs.name))
     elif lhs.is_expression():
         lhs = _generate_relational_expression__clone_if_needed(lhs)
         if lhs.is_relational():
@@ -1353,7 +1385,7 @@ def generate_relational_expression(etype, lhs, rhs):
             "specified without an index: %s\n    Is variable or parameter "
             "'%s' defined over an index that you did not specify?"
             % ({_eq:'==',_lt:'<',_le:'<='}.get(etype, etype),
-               rhs.cname(), rhs.cname()))
+               rhs.name, rhs.name))
     elif rhs.is_expression():
         rhs = _generate_relational_expression__clone_if_needed(rhs)
         if rhs.is_relational():
@@ -1370,11 +1402,17 @@ def generate_relational_expression(etype, lhs, rhs):
         # expression.
         for i,arg in enumerate(prevExpr._cloned_from):
             if arg == cloned_from[0]:
-                match.append(1)
+                match.append((i,0))
             elif arg == cloned_from[1]:
-                match.append(0)
+                match.append((i,1))
+        if etype == _eq:
+            raise TypeError(chainedInequalityErrorMessage())
         if len(match) == 1:
-            if match[0]:
+            if match[0][0] == match[0][1]:
+                raise TypeError(chainedInequalityErrorMessage(
+                    "Attempting to form a compound inequality with two "
+                    "%s bounds" % ('lower' if match[0][0] else 'upper',)))
+            if not match[0][1]:
                 cloned_from = prevExpr._cloned_from + (cloned_from[1],)
                 lhs = prevExpr
                 lhs_is_relational = True
@@ -1389,9 +1427,15 @@ def generate_relational_expression(etype, lhs, rhs):
                 buf = StringIO()
                 prevExpr.to_string(buf)
                 raise TypeError("Cannot create a compound inequality with "
-                      "identical upper and lower\n\tbounds with strict "
+                      "identical upper and lower\n\tbounds using strict "
                       "inequalities: constraint infeasible:\n\t%s and "
                       "%s < %s" % ( buf.getvalue().strip(), lhs, rhs ))
+            if match[0] == (0,0):
+                # This is a particularly weird case where someone
+                # evaluates the *same* inequality twice in a row.  This
+                # should always be an error (you can, for example, get
+                # it with "0 <= a >= 0").
+                raise TypeError(chainedInequalityErrorMessage())
             etype = _eq
         else:
             raise TypeError(chainedInequalityErrorMessage())
@@ -1462,6 +1506,7 @@ def generate_relational_expression(etype, lhs, rhs):
 # expressions of the type "a < b < c".  This provides a buffer to hold
 # the first inequality so the second inequality can access it later.
 generate_relational_expression.chainedInequality = None
+generate_relational_expression.call_info = None
 
 # [debugging] clone_counter is a count of the number of calls to
 # expr.clone() made during expression generation.
