@@ -14,10 +14,10 @@ from __future__ import division
 #            'asin', 'acos', 'atan', 'exp', 'sqrt', 'asinh', 'acosh',
 #            'atanh', 'ceil', 'floor' )
 
-import copy
 import logging
 import math
 import sys
+import traceback
 from six import advance_iterator
 from weakref import ref
 
@@ -35,8 +35,8 @@ except:
 from pyomo.core.base.component import Component
 #from pyomo.core.base.plugin import *
 from pyomo.core.base.numvalue import *
-from pyomo.core.base.numvalue import native_numeric_types
-from pyomo.core.base.var import _VarData
+from pyomo.core.base.numvalue import native_types, native_numeric_types
+from pyomo.core.base.var import _VarData, Var
 from pyomo.core.base.param import _ParamData
 from pyomo.core.base import expr_common as common
 import pyomo.core.base.expr_common
@@ -44,7 +44,11 @@ from pyomo.core.base.expr_common import \
     ensure_independent_trees as safe_mode, bypass_backreference, \
     _add, _sub, _mul, _div, _pow, _neg, _abs, _inplace, _unary, \
     _radd, _rsub, _rmul, _rdiv, _rpow, _iadd, _isub, _imul, _idiv, _ipow, \
-    _lt, _le, _eq
+    _lt, _le, _eq, clone_expression, chainedInequalityErrorMessage as cIEM
+
+# Wrap the common chainedInequalityErrorMessage to pass the local context
+chainedInequalityErrorMessage \
+    = lambda *x: cIEM(generate_relational_expression, *x)
 
 _stack = []
 
@@ -53,60 +57,23 @@ def _const_to_string(*args):
     args[1].write("%s" % args[0])
 
 
-def clone_expression(exp):
-    if exp.__class__ in native_numeric_types:
-        return exp
-    if exp.is_expression():
-        # It is important that this function calls the clone method not
-        # __copy__.  __copy__ and clone are the same for all classes
-        # that advertise "is_expression = True" except the
-        # _ExpressionData class (in which case clone does nothing so
-        # that the object remains persistent when generating
-        # expressions)
-        return exp.clone()
-    else:
-        return exp
-
 class EntangledExpressionError(Exception):
     pass
 
-def chainedInequalityErrorMessage(msg=None):
-    if msg is None:
-        msg = "Nonconstant relational expression used in an "\
-              "unexpected Boolean context."
-    buf = StringIO()
-    generate_relational_expression.chainedInequality.to_string(buf)
-    # We are about to raise an exception, so it's OK to reset chainedInequality
-    generate_relational_expression.chainedInequality = None
-    msg += """
-The inequality expression:
-    %s
-contains non-constant terms (variables) appearing in a Boolean context, e.g.:
-    if expression <= 5:
-This is generally invalid.  If you want to obtain the Boolean value of
-the expression based on the current variable values, explicitly evaluate
-the expression, e.g.:
-    if value(expression) <= 5:
-or
-    if value(expression <= 5):
-""" % ( buf.getvalue().strip(), )
-    return msg
 
-
-def identify_variables(expr, include_fixed=True, allow_duplicates=False):
+def identify_variables( expr,
+                        include_fixed=True,
+                        allow_duplicates=False,
+                        include_potentially_variable=False ):
     if not allow_duplicates:
         _seen = set()
-    expr = as_numeric(expr)
-    if expr.is_expression():
-        _stack = [ (expr._args, 0, len(expr._args)) ]
-    else:
-        _stack = [ ([expr], 0, 1) ]
+    _stack = [ ([expr], 0, 1) ]
     while _stack:
         _argList, _idx, _len = _stack.pop()
         while _idx < _len:
             _sub = _argList[_idx]
             _idx += 1
-            if type(_sub) in native_numeric_types:
+            if type(_sub) in native_types:
                 pass
             elif _sub.is_expression():
                 _stack.append(( _argList, _idx, _len ))
@@ -114,19 +81,28 @@ def identify_variables(expr, include_fixed=True, allow_duplicates=False):
                 _idx = 0
                 _len = len(_argList)
             elif isinstance(_sub, _VarData):
-                if include_fixed or not _sub.is_fixed():
+                if ( include_fixed
+                     or not _sub.is_fixed()
+                     or include_potentially_variable ):
                     if not allow_duplicates:
                         if id(_sub) in _seen:
                             continue
                         _seen.add(id(_sub))
                     yield _sub
+            elif include_potentially_variable and _sub._potentially_variable():
+                if not allow_duplicates:
+                    if id(_sub) in _seen:
+                        continue
+                    _seen.add(id(_sub))
+                yield _sub
 
 
 class _ExpressionBase(NumericValue):
     """An object that defines a mathematical expression that can be evaluated"""
 
     __pickle_slots__ = ('_args',)
-    __slots__ =  __pickle_slots__ + (('__weakref__', '_parent_expr') if safe_mode else ())
+    __slots__ =  __pickle_slots__ + (
+        ('__weakref__', '_parent_expr') if safe_mode else () )
     PRECEDENCE = 0
 
     def __init__(self, args):
@@ -134,27 +110,21 @@ class _ExpressionBase(NumericValue):
             self._parent_expr = None
         self._args = args
 
-    def __copy__(self):
-        """Clone this object using the specified arguments"""
-        return self.__class__( self._args.__class__(
-            (clone_expression(a) for a in self._args) ))
-
     def __getstate__(self):
         state = super(_ExpressionBase, self).__getstate__()
         for i in _ExpressionBase.__pickle_slots__:
            state[i] = getattr(self,i)
         if safe_mode:
-            state['_parent_expr'] = None
-            if self._parent_expr is not None:
-                _parent_expr = self._parent_expr()
-                if _parent_expr is not None:
-                    state['_parent_expr'] = _parent_expr
+            if not bypass_backreference and self._parent_expr is not None:
+                state['_parent_expr'] = self._parent_expr()
+            else:
+                state['_parent_expr'] = self._parent_expr
         return state
 
     def __setstate__(self, state):
         super(_ExpressionBase, self).__setstate__(state)
         if safe_mode:
-            if self._parent_expr is not None:
+            if self._parent_expr is not None and not bypass_backreference:
                 self._parent_expr = ref(self._parent_expr)
 
     def __nonzero__(self):
@@ -168,60 +138,40 @@ class _ExpressionBase(NumericValue):
         return buf.getvalue()
 
     def __call__(self, exception=None):
-        _result = []
-        _stack = [ (self, self._args, 0, len(self._args)) ]
-        while _stack:
-            _obj, _argList, _idx, _len = _stack.pop()
+        _stack = [ (self, self._args, 0, len(self._args), []) ]
+        while 1:  # Note: 1 is faster than True for Python 2.x
+            _obj, _argList, _idx, _len, _result = _stack.pop()
             while _idx < _len:
                 _sub = _argList[_idx]
                 _idx += 1
                 if type(_sub) in native_numeric_types:
-                    _result.append(_sub)
+                    _result.append( _sub )
                 elif _sub.is_expression():
-                    _stack.append(( _obj, _argList, _idx, _len ))
+                    _stack.append( (_obj, _argList, _idx, _len, _result) )
                     _obj     = _sub
                     _argList = _sub._args
                     _idx     = 0
                     _len     = len(_argList)
+                    _result  = []
                 else:
-                    _result.append(value(_sub))
-            _result.append( _obj._apply_operation(_result) )
-        assert(len(_result)==1)
-        return _result[0]
-
-
-        argList = self._args
-        _stack = [ (self, argList, 0, len(argList)) ]
-        _result = []
-        while _stack:
-            _obj, _argList, _idx, _len = _stack.pop()
-            if _idx < _len:
-                _sub = _argList[_idx]
-                _stack.append((_obj, _argList, _idx+1, _len))
-                if type(_sub) in native_numeric_types:
-                    _result.append(_sub)
-                    continue
-
-                if _sub.is_expression():
-                    argList = _sub._args
-                    _stack.append(( _sub, argList, 0, len(argList) ))
-                else:
-                    _result.append(value(_sub))
+                    _result.append( value(_sub) )
+            ans = _obj._apply_operation(_result)
+            if _stack:
+                _stack[-1][-1].append( ans )
             else:
-                _result.append( _obj._apply_operation(_result) )
-        assert(len(_result)==1)
-        return _result[0]
+                return ans
 
 
-    def clone(self):
-        ans = copy.copy(self)
-        ans._parent_expr = None
+    def clone(self, substitute=None):
+        ans = clone_expression(self, substitute)
+        if safe_mode:
+            ans._parent_expr = None
         return ans
 
-    def cname(self):
+    def getname(self, *args, **kwds):
         """The text name of this Expression function"""
         raise NotImplementedError("Derived expression (%s) failed to "\
-            "implement cname()" % ( str(self.__class__), ))
+            "implement getname()" % ( str(self.__class__), ))
 
     #
     # this method contrast with the is_fixed() method.  This method
@@ -249,79 +199,40 @@ class _ExpressionBase(NumericValue):
                 return False
         return True
 
+    # FIXME: These need to be made non-recursive
+    def _potentially_variable(self):
+        for a in self._args:
+            if a.__class__ not in native_numeric_types and a._potentially_variable():
+                return True
+        return False
+
     def is_expression(self):
         return True
 
+
     def polynomial_degree(self):
-        _typeList = TreeWalkerHelper.typeList
-
-        _stackMax = len(_stack)
-        _stackIdx = 0
-
-        _obj = self
-        _argList = _obj._args
-        _idx = 0
-        _len = len(_argList)
-        try:
-            _type = _typeList[_obj.__class__]
-            _ans = 0
-        except KeyError:
-            _type = 0
-            _ans = []
-        #_ans = 0 if _type else []
-        while 1: # Note: 1 is faster than True for Python 2.x
-            if _idx < _len:
+        _stack = [ (self, self._args, 0, len(self._args), []) ]
+        while 1:  # Note: 1 is faster than True for Python 2.x
+            _obj, _argList, _idx, _len, _result = _stack.pop()
+            while _idx < _len:
                 _sub = _argList[_idx]
                 _idx += 1
-                if _sub.__class__ in native_numeric_types:
-                    ans = 0
-                elif not _sub.is_expression():
-                    ans = 0 if _sub.is_fixed() else 1
+                if type(_sub) in native_numeric_types:
+                    _result.append( 0 )
+                elif _sub.is_expression():
+                    _stack.append( (_obj, _argList, _idx, _len, _result) )
+                    _obj     = _sub
+                    _argList = _sub._args
+                    _idx     = 0
+                    _len     = len(_argList)
+                    _result  = []
                 else:
-                    if _stackIdx == _stackMax:
-                        _stackMax += 1
-                        _stack.append((_obj, _argList, _len, _type, _idx, _ans))
-                    else:
-                        _stack[_stackIdx] = \
-                                _obj, _argList, _len, _type, _idx, _ans
-
-                    _obj = _sub
-                    _argList = _obj._args
-                    _idx = 0
-                    _len = len(_argList)
-                    _type = _typeList.get(_obj.__class__, 0)
-                    _ans = 0 if _type else []
-
-                    _stackIdx += 1
-                    continue
+                    _result.append( 0 if _sub.is_fixed() else 1 )
+            ans = _obj._polynomial_degree(_result)
+            if _stack:
+                _stack[-1][-1].append( ans )
             else:
-                if not _type:
-                    _ans = _obj._polynomial_degree(_ans)
-                if _stackIdx == 0:
-                    return _ans
-                ans = _ans
-                _stackIdx -= 1
-                _obj, _argList, _len, _type, _idx, _ans = _stack[_stackIdx]
-
-            #_objType = type(_obj)
-            if _type is 1:#_objType is _SumExpression:
-                if _ans is not None:
-                    if ans is None or ans > _ans:
-                        _ans = ans
-            elif _type is 2:#_objType is _ProductExpression:
-                if _ans is not None:
-                    if ans is None:
-                        _ans = None
-                    else:
-                        _ans += ans
-            elif _type is 3:#_objType is _NegationExpression:
-                _ans = ans
-            elif _type is 4:#_objType is _LinearExpression_Pool
-                if ans == 1:
-                    _ans = ans
-                    _idx = _len
-            else:
-                _ans.append(ans)
+                return ans
 
 
     def _polynomial_degree(self, ans):
@@ -381,11 +292,11 @@ class _ExpressionBase(NumericValue):
         elif _sub.__class__ is NumericConstant:
             ostream.write(str(_sub()))
         else:
-            ostream.write(_sub.cname(True, _name_buffer))
+            ostream.write(_sub.getname(True, _name_buffer))
 
     def _to_string_prefix(self, ostream, verbose):
         if verbose:
-            ostream.write(self.cname())
+            ostream.write(self.getname())
 
     def _to_string_infix(self, ostream, idx, verbose):
         if verbose:
@@ -399,25 +310,25 @@ class _NegationExpression(_ExpressionBase):
 
     PRECEDENCE = 4
 
-    def cname(self):
+    def getname(self, *args, **kwds):
         return 'neg'
 
     def _polynomial_degree(self, result):
-        return result.pop()
+        return result[0]
 
     def _precedence(self):
         return _NegationExpression.PRECEDENCE
 
     def _to_string_prefix(self, ostream, verbose):
         if verbose:
-            ostream.write(self.cname())
+            ostream.write(self.getname())
         elif not self._args[0].is_expression and _NegationExpression.PRECEDENCE <= self._args[0]._precedence():
             ostream.write("-")
         else:
             ostream.write("- ")
 
     def _apply_operation(self, result):
-        return -result.pop()
+        return -result[0]
 
 class _UnaryFunctionExpression(_ExpressionBase):
     """An object that defines a mathematical expression that can be evaluated"""
@@ -434,53 +345,60 @@ class _UnaryFunctionExpression(_ExpressionBase):
         self._fcn = fcn
         self._name = name
 
-    def __copy__(self):
-        """Clone this object using the specified arguments"""
-        return self.__class__( self._args.__class__(
-            (clone_expression(a) for a in self._args) ),
-                               self._name,
-                               self._fcn )
-
     def __getstate__(self):
         result = super(_UnaryFunctionExpression, self).__getstate__()
         for i in _UnaryFunctionExpression.__slots__:
             result[i] = getattr(self, i)
         return result
 
-    def cname(self):
+    def getname(self, *args, **kwds):
         return self._name
 
     def _to_string_prefix(self, ostream, verbose):
-        ostream.write(self.cname())
+        ostream.write(self.getname())
 
     def _polynomial_degree(self, result):
-        if result.pop() == 0:
+        if result[0] == 0:
             return 0
         else:
             return None
 
     def _apply_operation(self, result):
-        return self._fcn(result.pop())
+        return self._fcn(result[0])
 
 # Backwards compatibility: Coopr 3.x expected a slightly less informative name
 _IntrinsicFunctionExpression =  _UnaryFunctionExpression
 
 
 class _ExternalFunctionExpression(_ExpressionBase):
-    __slots__ = ()
+    __slots__ = ('_fcn',)
 
-    def cname(self):
-        return self._fcn.cname()
+    def __init__(self, fcn, args):
+        """Construct a call to an external function"""
+        if safe_mode:
+            self._parent_expr = None
+            for x in args:
+                if isinstance(x, _ExpressionBase):
+                    if x._parent_expr:
+                        raise EntangledExpressionError(x)
+                    x._parent_expr = bypass_backreference or ref(self)
+        self._args = tuple(
+            x if isinstance(x, basestring) else as_numeric(x)
+            for x in args )
+        self._fcn = fcn
+
+    def getname(self, *args, **kwds):
+        return self._fcn.getname(*args, **kwds)
 
     def _polynomial_degree(self, result):
-        if result.pop() == 0:
+        if result[0] == 0:
             return 0
         else:
             return None
 
     def _apply_operation(self, result):
         """Evaluate the expression"""
-        return self._fcn.evaluate(result.pop())
+        return self._fcn.evaluate( result )
 
     def _inline_operator(self):
         return ', '
@@ -495,11 +413,6 @@ class _AbsExpression(_UnaryFunctionExpression):
     def __init__(self, arg):
         super(_AbsExpression, self).__init__(arg, 'abs', abs)
 
-    def __copy__(self):
-        """Clone this object using the specified arguments"""
-        return self.__class__( self._args.__class__(
-            (clone_expression(a) for a in self._args) ) )
-
 
 class _PowExpression(_ExpressionBase):
 
@@ -513,8 +426,7 @@ class _PowExpression(_ExpressionBase):
         # integer, it is also polynomial.  While we would like to just
         # call this a non-polynomial expression, these exceptions occur
         # too frequently (and in particular, a**2)
-        r = result.pop()
-        l = result.pop()
+        l,r = result
         if r == 0:
             if l == 0:
                 return 0
@@ -546,23 +458,43 @@ class _PowExpression(_ExpressionBase):
             self._args[0].__class__ in native_numeric_types or \
             self._args[0].is_constant()
 
+    # the base class implementation is fine
+    #def _potentially_variable(self)
+
     def _precedence(self):
         return _PowExpression.PRECEDENCE
 
     def _apply_operation(self, result):
-        _r = result.pop()
-        _l = result.pop()
+        _l, _r = result
         return _l ** _r
 
-    def cname(self):
+    def getname(self, *args, **kwds):
         return 'pow'
 
     def _inline_operator(self):
         return '**'
 
 
+class _LinearOperatorExpression(_ExpressionBase):
+    """An 'abstract' class that defines the polynominal degree for a simple
+    linear operator
+    """
 
-class _InequalityExpression(_ExpressionBase):
+    __slots__ = ()
+
+    def _polynomial_degree(self, result):
+        # NB: We can't use max() here because None (non-polynomial)
+        # overrides a numeric value (and max() just ignores it)
+        ans = 0
+        for x in result:
+            if x is None:
+                return None
+            elif ans < x:
+                ans = x
+        return ans
+
+
+class _InequalityExpression(_LinearOperatorExpression):
     """An object that defines a series of less-than or
     less-than-or-equal expressions"""
 
@@ -575,12 +507,6 @@ class _InequalityExpression(_ExpressionBase):
         self._strict = strict
         self._cloned_from = cloned_from
 
-    def __copy__(self):
-        return self.__class__( self._args.__class__(
-            (clone_expression(a) for a in self._args) ),
-                               copy.copy(self._strict),
-                               copy.copy(self._cloned_from) )
-
     def __getstate__(self):
         result = super(_InequalityExpression, self).__getstate__()
         for i in _InequalityExpression.__slots__:
@@ -590,7 +516,9 @@ class _InequalityExpression(_ExpressionBase):
     def __nonzero__(self):
         if generate_relational_expression.chainedInequality is not None:
             raise TypeError(chainedInequalityErrorMessage())
-        if not self.is_constant():
+        if not self.is_constant() and len(self._args) == 2:
+            generate_relational_expression.call_info \
+                = traceback.extract_stack(limit=2)[-2]
             generate_relational_expression.chainedInequality = self
             return True
 
@@ -605,11 +533,10 @@ class _InequalityExpression(_ExpressionBase):
         return _InequalityExpression.PRECEDENCE
 
     def _apply_operation(self, result):
-        args = result[-len(self._args):]
-        result[-len(self._args):] = []
-        _l = args.pop(0)
-        for i, a in enumerate(args):
-            if self._strict[i]:
+        for i, a in enumerate(result):
+            if not i:
+                pass
+            elif self._strict[i-1]:
                 if not _l < a:
                     return False
             else:
@@ -625,7 +552,7 @@ class _InequalityExpression(_ExpressionBase):
         ostream.write( '  <  ' if self._strict[idx-1] else '  <=  ' )
 
 
-class _EqualityExpression(_ExpressionBase):
+class _EqualityExpression(_LinearOperatorExpression):
     """An object that defines a equal-to expression"""
 
     __slots__ = ()
@@ -645,7 +572,8 @@ class _EqualityExpression(_ExpressionBase):
         return _EqualityExpression.PRECEDENCE
 
     def _apply_operation(self, result):
-        return result.pop() == result.pop()
+        _l, _r = result
+        return _l == _r
 
     def _to_string_prefix(self, ostream, verbose):
         pass
@@ -667,22 +595,22 @@ class _ProductExpression(_ExpressionBase):
         # NB: We can't use sum() here because None (non-polynomial)
         # overrides a numeric value (and sum() just ignores it - or
         # errors in py3k)
-        a = result.pop()
-        b = result.pop()
+        a, b = result
         if a is None or b is None:
             return None
         else:
             return a + b
 
 
-    def cname(self):
+    def getname(self, *args, **kwds):
         return 'prod'
 
     def _inline_operator(self):
         return ' * '
 
     def _apply_operation(self, result):
-        return result.pop() * result.pop()
+        _l, _r = result
+        return _l * _r
 
 
 class _DivisionExpression(_ExpressionBase):
@@ -698,23 +626,21 @@ class _DivisionExpression(_ExpressionBase):
         # NB: We can't use sum() here because None (non-polynomial)
         # overrides a numeric value (and sum() just ignores it - or
         # errors in py3k)
-        d = result.pop()
-        n = result.pop()
+        n,d = result
         if d == 0:
             return n
         else:
             return None
 
 
-    def cname(self):
+    def getname(self, *args, **kwds):
         return 'div'
 
     def _inline_operator(self):
         return ' / '
 
     def _apply_operation(self, result):
-        _r = result.pop()
-        _l = result.pop()
+        _l, _r = result
         return _l / _r
 
 
@@ -726,7 +652,7 @@ class _DivisionExpression(_ExpressionBase):
 
 
 
-class _SumExpression(_ExpressionBase):
+class _SumExpression(_LinearOperatorExpression):
     """An object that defines a simple summation of expressions"""
 
     __slots__ = ()
@@ -745,24 +671,10 @@ class _SumExpression(_ExpressionBase):
             else:
                 ostream.write(' + ')
 
-    def _polynomial_degree(self, result):
-        # NB: We can't use max() here because None (non-polynomial)
-        # overrides a numeric value (and max() just ignores it)
-        ans = 0
-        for x in self._args:
-            _pd = result.pop()
-            if ans is not None:
-                if _pd is not None:
-                    if _pd > ans:
-                        ans = _pd
-                else:
-                    ans = None
-        return ans
-
     def _apply_operation(self, result):
-        return sum(result.pop() for x in self._args)
+        return sum(result)
 
-    def cname(self):
+    def getname(self, *args, **kwds):
         return 'sum'
 
     def __iadd__(self, other):
@@ -788,6 +700,10 @@ class _SumExpression(_ExpressionBase):
                 raise EntangledExpressionError(self, other)
             if _type is _SumExpression:
                 self._args.extend(other._args)
+                if safe_mode:
+                    for x in other._args:
+                        if x.is_expression():
+                            x._parent_expr = bypass_backreference or ref(self)
                 other._args = [] # for safety
                 return self
             if safe_mode:
@@ -798,7 +714,7 @@ class _SumExpression(_ExpressionBase):
                 "Argument for expression '%s' is an indexed numeric "
                 "value\nspecified without an index:\n\t%s\nIs this "
                 "value defined over an index that you did not specify?"
-                % (etype, other.cname(True), ) )
+                % (etype, other.name, ) )
         elif other.is_constant():
             other = other()
 
@@ -837,7 +753,16 @@ class _SumExpression(_ExpressionBase):
             if safe_mode and other._parent_expr:# is not None:
                 raise EntangledExpressionError(self, other)
             if _type is _SumExpression:
-                self._args.extend(-i for i in other._args)
+                if safe_mode:
+                    for x in other._args:
+                        if x.is_expression():
+                            x._parent_expr = None
+                _other_args = tuple(-i for i in other._args)
+                self._args.extend(_other_args)
+                if safe_mode:
+                    for x in _other_args:
+                        if x.is_expression():
+                            x._parent_expr = bypass_backreference or ref(self)
                 other._args = [] # for safety
                 return self
             tmp = other
@@ -850,7 +775,7 @@ class _SumExpression(_ExpressionBase):
                 "Argument for expression '%s' is an indexed numeric "
                 "value\nspecified without an index:\n\t%s\nIs this "
                 "value defined over an index that you did not specify?"
-                % (etype, other.cname(), ) )
+                % (etype, other.name, ) )
         elif other.is_constant():
             other = - ( other() )
 
@@ -889,22 +814,16 @@ class Expr_if(_ExpressionBase):
         self._else = as_numeric(ELSE)
         self._args = (self._if, self._then, self._else)
 
-    def __copy__(self):
-        """Clone this object using the specified arguments"""
-        return self.__class__(IF=clone_expression(self._if),
-                              THEN=clone_expression(self._then),
-                              ELSE=clone_expression(self._else))
-
     def __getstate__(self):
         state = super(Expr_if, self).__getstate__()
         for i in Expr_if.__slots__:
-            result[i] = getattr(self, i)
-        return result
+            state[i] = getattr(self, i)
+        return state
 
     def _arguments(self):
         return ( self._if, self._then, self._else )
 
-    def cname(self):
+    def getname(self, *args, **kwds):
         return "Expr_if"
 
     def is_constant(self):
@@ -925,17 +844,17 @@ class Expr_if(_ExpressionBase):
         else:
             return False
 
+    # the base class implementation is fine
+    #def _potentially_variable(self)
+
     def _polynomial_degree(self, result):
-        _else = result.pop()
-        _then = result.pop()
-        _if = result.pop()
+        _if, _then, _else = result
         if _if == 0:
-            if self._if():
-                return _then
-            else:
-                return _else
-        else:
-            return None
+            try:
+                return _then if self._if() else _else
+            except:
+                pass
+        return None
 
     def _to_string_term(self, ostream, _idx, _sub, _name_buffer, verbose):
         ostream.write("%s=( " % ('if','then','else')[_idx], )
@@ -943,7 +862,7 @@ class Expr_if(_ExpressionBase):
         ostream.write(" )")
 
     def _to_string_prefix(self, ostream, verbose):
-        ostream.write(self.cname())
+        ostream.write(self.getname())
 
     def _to_string_infix(self, ostream, idx, verbose):
         ostream.write(", ")
@@ -980,10 +899,53 @@ class Expr_if(_ExpressionBase):
         ostream.write(" ) )")
 
     def _apply_operation(self, result):
-        _e = result.pop()
-        _t = result.pop()
-        _i = result.pop()
-        return _t if _i else _e
+        _if, _then, _else = result
+        return _then if _if else _else
+
+
+class _GetItemExpression(_ExpressionBase):
+    """Expression to call "__getitem__" on the base"""
+
+    __slots__ = ('_base',)
+    PRECEDENCE = 1
+
+    def _precedence(self):
+        return _GetItemExpression.PRECEDENCE
+
+    def __init__(self, base, args):
+        """Construct an expression with an operation and a set of arguments"""
+        if safe_mode:
+            self._parent_expr = None
+        self._args = args
+        self._base = base
+
+    def __getstate__(self):
+        result = super(_GetItemExpression, self).__getstate__()
+        for i in _GetItemExpression.__slots__:
+            result[i] = getattr(self, i)
+        return result
+
+    def getname(self, *args, **kwds):
+        return self._base.getname(*args, **kwds)
+
+    def is_constant(self):
+        return False
+
+    def is_fixed(self):
+        return not isinstance(self._base, Var)
+
+    def _polynomial_degree(self, result):
+        return 0 if self.is_fixed() else 1
+
+    def _apply_operation(self, result):
+        return value(self._base.__getitem__( tuple(result) ))
+
+    def _to_string_prefix(self, ostream, verbose):
+        ostream.write(self.name)
+
+    def resolve_template(self):
+        return self._base.__getitem__(tuple(value(i) for i in self._args))
+
 
 _LinearExpression_Pool = []
 
@@ -1002,15 +964,6 @@ class _LinearExpression(_ExpressionBase):
             self._args = []
             self._coef = {}
 
-    def __copy__(self):
-        """Clone this object using the specified arguments"""
-        return self.__class__(
-            copy.copy(self._const),
-            self._args.__class__(
-                (clone_expression(a) for a in self._args) ),
-            tuple( (clone_expression(self._coef[id(v)]) for v in self._args) )
-        )
-
     def __getstate__(self):
         state = super(_LinearExpression, self).__getstate__()
         for i in _LinearExpression.__slots__:
@@ -1044,7 +997,7 @@ class _LinearExpression(_ExpressionBase):
             ans.extend(self._args)
             return ans
 
-    def cname(self):
+    def getname(self, *args, **kwds):
         return 'linear'
 
     def is_constant(self):
@@ -1069,7 +1022,7 @@ class _LinearExpression(_ExpressionBase):
                 if _idx:
                     coef = abs(coef)
                 if coef == 1:
-                    ostream.write(_sub.cname(True, _name_buffer))
+                    ostream.write(_sub.getname(True, _name_buffer))
                     return
                 ostream.write(str(coef))
             elif coef.is_expression():
@@ -1077,7 +1030,7 @@ class _LinearExpression(_ExpressionBase):
                                 precedence=_ProductExpression.PRECEDENCE )
             else:
                 ostream.write(str(coef))
-            ostream.write("*%s" % (_sub.cname(True, _name_buffer)))
+            ostream.write("*%s" % (_sub.getname(True, _name_buffer)))
 
     def _to_string_infix(self, ostream, idx, verbose):
         if verbose:
@@ -1095,15 +1048,17 @@ class _LinearExpression(_ExpressionBase):
             else:
                 ostream.write(' + ')
 
-    def _apply_operation(self, result):
-        if not self._args:
-            return value(self._const)
+    def _polynomial_degree(self, result):
+        if result:
+            return max(result)
+        else:
+            return 0
 
-        r = result[-len(self._args):]
-        result[-len(self._args):] = []
+    def _apply_operation(self, result):
+        assert( len(result) == len(self._args) )
         ans = value(self._const)
         for i,v in enumerate(self._args):
-            ans += r[i] * value(self._coef[id(v)])
+            ans += value(self._coef[id(v)]) * result[i]
         return ans
 
     def __iadd__(self, other, _reversed=0):
@@ -1123,6 +1078,8 @@ class _LinearExpression(_ExpressionBase):
             other._const = 0
             other._args = []
             other._coef = {}
+            if safe_mode:
+                other._parent_expr = None
             _LinearExpression_Pool.append(other)
             return self
         elif isinstance(other, _VarData):
@@ -1200,6 +1157,8 @@ class _LinearExpression(_ExpressionBase):
                 other._const = 0
                 other._args = []
                 other._coef = {}
+                if safe_mode:
+                    other._parent_expr = None
                 _LinearExpression_Pool.append(other)
             else:
                 return super(_LinearExpression, self).__isub__(other)
@@ -1259,6 +1218,8 @@ class _LinearExpression(_ExpressionBase):
                 for i in self._coef:
                     self._coef[i] *= other._const
                 other._const = 0
+                if safe_mode:
+                    other._parent_expr = None
                 _LinearExpression_Pool.append(other)
             else:
                 return super(_LinearExpression, self).__imul__(other)
@@ -1320,6 +1281,8 @@ class _LinearExpression(_ExpressionBase):
                 for i in self._coef:
                     self._coef[i] /= other._const
                 other._const = 0
+                if safe_mode:
+                    other._parent_expr = None
                 _LinearExpression_Pool.append(other)
             else:
                 return super(_LinearExpression, self).__imul__(other)
@@ -1404,7 +1367,7 @@ def generate_expression(etype, _self, _other):
                 "Argument for expression '%s' is an indexed numeric "
                 "value\nspecified without an index:\n\t%s\nIs this "
                 "value defined over an index that you did not specify?"
-                % (etype, _other.cname(), ) )
+                % (etype, _other.name, ) )
         elif _other.is_constant():
             _other = _other()
 
@@ -1626,7 +1589,7 @@ def generate_relational_expression(etype, lhs, rhs):
             "specified without an index: %s\n    Is variable or parameter "
             "'%s' defined over an index that you did not specify?"
             % ({_eq:'==',_lt:'<',_le:'<='}.get(etype, etype),
-               lhs.cname(), lhs.cname()))
+               lhs.name, lhs.name))
     elif lhs.is_expression():
         if lhs.is_relational():
             lhs_is_relational = True
@@ -1638,7 +1601,7 @@ def generate_relational_expression(etype, lhs, rhs):
             "specified without an index: %s\n    Is variable or parameter "
             "'%s' defined over an index that you did not specify?"
             % ({_eq:'==',_lt:'<',_le:'<='}.get(etype, etype),
-               rhs.cname(), rhs.cname()))
+               rhs.name, rhs.name))
     elif rhs.is_expression():
         if rhs.is_relational():
             rhs_is_relational = True
@@ -1654,11 +1617,17 @@ def generate_relational_expression(etype, lhs, rhs):
         # expression.
         for i,arg in enumerate(prevExpr._cloned_from):
             if arg == cloned_from[0]:
-                match.append(1)
+                match.append((i,0))
             elif arg == cloned_from[1]:
-                match.append(0)
+                match.append((i,1))
+        if etype == _eq:
+            raise TypeError(chainedInequalityErrorMessage())
         if len(match) == 1:
-            if match[0]:
+            if match[0][0] == match[0][1]:
+                raise TypeError(chainedInequalityErrorMessage(
+                    "Attempting to form a compound inequality with two "
+                    "%s bounds" % ('lower' if match[0][0] else 'upper',)))
+            if not match[0][1]:
                 cloned_from = prevExpr._cloned_from + (cloned_from[1],)
                 lhs = prevExpr
                 lhs_is_relational = True
@@ -1673,9 +1642,15 @@ def generate_relational_expression(etype, lhs, rhs):
                 buf = StringIO()
                 prevExpr.to_string(buf)
                 raise TypeError("Cannot create a compound inequality with "
-                      "identical upper and lower\n\tbounds with strict "
-                      "inequalities: constraint trivially infeasible:\n\t%s and "
+                      "identical upper and lower\n\tbounds using strict "
+                      "inequalities: constraint infeasible:\n\t%s and "
                       "%s < %s" % ( buf.getvalue().strip(), lhs, rhs ))
+            if match[0] == (0,0):
+                # This is a particularly weird case where someone
+                # evaluates the *same* inequality twice in a row.  This
+                # should always be an error (you can, for example, get
+                # it with "0 <= a >= 0").
+                raise TypeError(chainedInequalityErrorMessage())
             etype = _eq
         else:
             raise TypeError(chainedInequalityErrorMessage())
@@ -1764,7 +1739,7 @@ def generate_intrinsic_function_expression(arg, name, fcn):
     if arg.is_indexed():
         raise ValueError("Argument for intrinsic function '%s' is an "\
             "n-ary numeric value: %s\n    Have you given variable or "\
-            "parameter '%s' an index?" % (name, arg.cname(), arg.cname()))
+            "parameter '%s' an index?" % (name, arg.name, arg.name))
     return _UnaryFunctionExpression((arg,), name, fcn)
 
 # [debugging] clone_counter is a count of the number of calls to
