@@ -125,6 +125,11 @@ class _ExpressionData(NumericValue):
         """A boolean indicating whether this expression is fixed."""
         raise NotImplementedError
 
+    # _ExpressionData should never return False because
+    # they can store subexpressions that contain variables
+    def _potentially_variable(self):
+        return True
+
 class _GeneralExpressionDataImpl(_ExpressionData):
     """
     An object that defines an expression that is never cloned
@@ -249,7 +254,7 @@ class Expression(IndexedComponent):
     def __new__(cls, *args, **kwds):
         if cls != Expression:
             return super(Expression, cls).__new__(cls)
-        if args == () or (args[0] == UnindexedComponent_set and len(args)==1):
+        if args == () or (type(args[0]) == set and args[0] == UnindexedComponent_set and len(args)==1):
             return SimpleExpression.__new__(SimpleExpression)
         else:
             return IndexedExpression.__new__(IndexedExpression)
@@ -281,9 +286,9 @@ class Expression(IndexedComponent):
                   else self._index)
              ],
             self.iteritems(),
-            ("Key","Expression"),
+            ("Expression",),
             lambda k,v: \
-               [k, "Undefined" if v.expr is None else v.expr]
+               ["Undefined" if v.expr is None else v.expr]
             )
 
     def display(self, prefix="", ostream=None):
@@ -293,7 +298,7 @@ class Expression(IndexedComponent):
         if ostream is None:
             ostream = sys.stdout
         tab="    "
-        ostream.write(prefix+self.cname()+" : ")
+        ostream.write(prefix+self.local_name+" : ")
         ostream.write("Size="+str(len(self)))
 
         ostream.write("\n")
@@ -326,7 +331,7 @@ class Expression(IndexedComponent):
            (not None in new_values):
             raise KeyError(
                 "Cannot store value for scalar Expression"
-                "="+self.cname(True)+"; no value with index "
+                "="+self.name+"; no value with index "
                 "None in input new values map.")
 
         for index, new_value in iteritems(new_values):
@@ -350,7 +355,7 @@ class Expression(IndexedComponent):
             raise KeyError(
                 "Cannot set the value of Expression '%s' with "
                 "invalid index '%s'"
-                % (self.cname(True), str(ndx)))
+                % (self.name, str(ndx)))
         #
         # Set the value
         #
@@ -362,7 +367,7 @@ class Expression(IndexedComponent):
         if __debug__ and logger.isEnabledFor(logging.DEBUG):
             logger.debug(
                 "Constructing Expression, name=%s, from data=%s"
-                % (self.cname(True), str(data)))
+                % (self.name, str(data)))
 
         if self._constructed:
             return
@@ -436,7 +441,7 @@ class SimpleExpression(_GeneralExpressionData, Expression):
             "Accessing the expression of expression '%s' "
             "before the Expression has been constructed (there "
             "is currently no value to return)."
-            % (self.cname(True)))
+            % (self.name))
     @expr.setter
     def expr(self, expr):
         """Set the expression on this expression."""
@@ -464,7 +469,7 @@ class SimpleExpression(_GeneralExpressionData, Expression):
             "Setting the expression of expression '%s' "
             "before the Expression has been constructed (there "
             "is currently no object to set)."
-            % (self.cname(True)))
+            % (self.name))
 
     def is_constant(self):
         """A boolean indicating whether this expression is constant."""
@@ -474,7 +479,7 @@ class SimpleExpression(_GeneralExpressionData, Expression):
             "Accessing the is_constant flag of expression '%s' "
             "before the Expression has been constructed (there "
             "is currently no value to return)."
-            % (self.cname(True)))
+            % (self.name))
 
     def is_fixed(self):
         """A boolean indicating whether this expression is fixed."""
@@ -484,7 +489,7 @@ class SimpleExpression(_GeneralExpressionData, Expression):
             "Accessing the is_fixed flag of expression '%s' "
             "before the Expression has been constructed (there "
             "is currently no value to return)."
-            % (self.cname(True)))
+            % (self.name))
 
     #
     # Leaving this method for backward compatibility reasons.
@@ -496,13 +501,13 @@ class SimpleExpression(_GeneralExpressionData, Expression):
             raise KeyError(
                 "SimpleExpression object '%s' does not accept "
                 "index values other than None. Invalid value: %s"
-                % (self.cname(True), index))
+                % (self.name, index))
         if (type(expr) is tuple) and \
            (expr == Expression.Skip):
             raise ValueError(
                 "Expression.Skip can not be assigned "
                 "to an Expression that is not indexed: %s"
-                % (self.cname(True)))
+                % (self.name))
         self.set_value(expr)
         return self
 
