@@ -13,6 +13,8 @@ import pyutilib.misc
 
 from pyomo.core.base.component import Component, ActiveComponent
 from pyomo.core.base.config import PyomoOptions
+from pyomo.core.base.template_expr import TemplateExpressionError
+from pyomo.util import DeveloperError
 
 from six import PY3, itervalues, iteritems, advance_iterator
 import sys
@@ -229,6 +231,7 @@ class _IndexedComponent_slicer(object):
             _IndexedComponent_slicer.call, idx ) )
         return self
 
+
 class IndexedComponent(Component):
     """
     This is the base class for all indexed modeling components.
@@ -314,9 +317,8 @@ class IndexedComponent(Component):
         if UnindexedComponent_set != self._index:
             self._data = {}
         else:
-            raise NotImplementedError(
-                "Derived scalar component %s failed to define clear().\n"
-                "\tPlease report this to the Pyomo developers"
+            raise DeveloperError(
+                "Derived scalar component %s failed to define clear()."
                 % (self.__class__.__name__,))
 
     def index_set(self):
@@ -380,7 +382,7 @@ You can silence this warning by one of three ways:
     3) If you intend to iterate over a component that may be empty, test
        if the component is empty first and avoid iteration in the case
        where it is empty.
-""" % (self.cname(True),) )
+""" % (self.name,) )
 
             if not hasattr(self._index, 'ordered') or not self._index.ordered:
                 #
@@ -456,7 +458,7 @@ You can silence this warning by one of three ways:
                 idx_str = "[" + str(ndx) + "]"
             raise ValueError(
                 "Error retrieving component %s%s: The component has "
-                "not been constructed." % ( self.cname(True), idx_str,) )
+                "not been constructed." % ( self.name, idx_str,) )
         if ndx is None and not self.is_indexed():
             self._data[ndx] = self  # FIXME: should this be a weakref?!?
             return self
@@ -495,23 +497,25 @@ You can silence this warning by one of three ways:
         if not self.is_indexed():
             msg = "Error accessing indexed component: " \
                   "Cannot treat the scalar component '%s' as an array" \
-                  % ( self.cname(True), )
+                  % ( self.name, )
             raise KeyError(msg)
         #
         # Raise an exception
         #
         msg = "Error accessing indexed component: " \
                   "Index '%s' is not valid for array component '%s'" \
-                  % ( ndx, self.cname(True), )
+                  % ( ndx, self.name, )
         raise KeyError(msg)
 
 
     def _processUnhashableIndex(self, ndx, _exception):
         """Process a call to __getitem__ with unhashable elements
 
-        There are two basic ways to get here:
-          1) the index constains one or more slices
-          2) the index contains a Pyomo (Simple)COmponent
+        There are three basic ways to get here:
+          1) the index constains one or more slices or ellipsis
+          2) the index contains an unhashable type (e.g., a Pyomo
+             (Simple)Component
+          3) the index contains an IndexTemplate
         """
         #
         # Iterate through the index and look for slices and constant
@@ -526,6 +530,12 @@ You can silence this warning by one of three ways:
         #
         if type(ndx) not in (tuple, list):
             ndx = [ndx]
+        else:
+            # We would normally do "flatten()" here, but the current
+            # (10/2016) implementation of flatten() is too aggressive:
+            # it will attempt to expand *any* iterable, including
+            # SimpleParam.
+            ndx = pyutilib.misc.flatten_tuple(tuple(ndx))
 
         for i,val in enumerate(ndx):
             if type(val) is slice:
@@ -557,6 +567,35 @@ You can silence this warning by one of three ways:
 
             try:
                 _num_val = val.as_numeric()
+                # Attempt to retrieve the numeric value .. if this
+                # is a template expression generation, then it
+                # should raise a TemplateExpressionError
+                try:
+                    # Disable all logging for the time being.  We are
+                    # not keeping the result of this calculation - only
+                    # seeing if it is possible.  Any errors generated
+                    # evaluating the expression are not informative to
+                    # the user
+                    active_level = logging.root.manager.disable
+                    logging.disable(logging.CRITICAL)
+                    _num_val()
+                except TemplateExpressionError:
+                    # Not good: we have to defer this import to now
+                    # due to circular imports (expr imports _VarData
+                    # imports indexed_component, but we need expr
+                    # here
+                    from pyomo.core.base import expr as EXPR
+                    return EXPR._GetItemExpression(self, tuple(ndx))
+                except:
+                    # There are other ways we could get an exception
+                    # that is not TemplateExpressionError; most notably,
+                    # evaluating a Param / Var that is not initialized.
+                    # At this point, we will silently eat that
+                    # error... it will come back again below.
+                    pass
+                finally:
+                    logging.disable(active_level)
+
                 if _num_val.is_constant():
                     _found_numeric = True
                     val = _num_val()
@@ -567,7 +606,7 @@ index %s is a fixed but not constant value.  This is likely not what you
 meant to do, as if you later change the fixed value of the object this
 lookup will not change.  If you understand the implications of using
 fixed but not constant values, you can get the current value using the
-value() function.""" % ( self.cname(True), i ))
+value() function.""" % ( self.name, i ))
                 else:
                     raise RuntimeError(
 """Error retrieving the value of an indexed item %s:
@@ -575,7 +614,7 @@ index %s is not a constant value.  This is likely not what you meant to
 do, as if you later change the fixed value of the object this lookup
 will not change.  If you understand the implications of using
 non-constant values, you can get the current value of the object using
-the value() function.""" % ( self.cname(True), i ))
+the value() function.""" % ( self.name, i ))
             except AttributeError:
                 pass
             if ellipsis is None:
@@ -591,14 +630,13 @@ the value() function.""" % ( self.cname(True), i ))
         else:
             raise TypeError(
                 "%s found when trying to retrieve index for component %s"
-                % (_exception, self.cname(True)) )
+                % (_exception, self.name) )
 
 
     def _default(self, index):
         """Returns the default component data value"""
-        raise NotImplementedError(
-            "Derived component %s failed to define _default().\n"
-            "\tPlease report this to the Pyomo developers"
+        raise DeveloperError(
+            "Derived component %s failed to define _default()."
             % (self.__class__.__name__,))
 
     def set_value(self, value):
@@ -610,10 +648,9 @@ the value() function.""" % ( self.cname(True), i ))
                 "\tFor example, model.%s[i] = value"
                 % (self.name, self.name))
         else:
-            raise NotImplementedError(
+            raise DeveloperError(
                 "Derived component %s failed to define set_value() "
-                "for scalar instances.\n"
-                "\tPlease report this to the Pyomo developers"
+                "for scalar instances."
                 % (self.__class__.__name__,))
 
     def id_index_map(self):
