@@ -256,7 +256,7 @@ class Objective(ActiveIndexedComponent):
     def __new__(cls, *args, **kwds):
         if cls != Objective:
             return super(Objective, cls).__new__(cls)
-        if args == ():
+        if args == () or (type(args[0]) == set and args[0] == UnindexedComponent_set and len(args)==1):
             return SimpleObjective.__new__(SimpleObjective)
         else:
             return IndexedObjective.__new__(IndexedObjective)
@@ -274,7 +274,7 @@ class Objective(ActiveIndexedComponent):
         """
         if __debug__ and logger.isEnabledFor(logging.DEBUG):
             logger.debug(
-                "Constructing objective %s" % (self.cname(True)))
+                "Constructing objective %s" % (self.name))
         if self._constructed:
             return
         self._constructed = True
@@ -310,7 +310,7 @@ class Objective(ActiveIndexedComponent):
                     logger.error(
                         "Rule failed when generating expression for "
                         "objective %s:\n%s: %s"
-                        % (self.cname(True),
+                        % (self.name,
                            type(err).__name__,
                            err))
                     raise
@@ -348,7 +348,7 @@ class Objective(ActiveIndexedComponent):
                     logger.error(
                         "Rule failed when generating expression for"
                         " objective %s with index %s:\n%s: %s"
-                        % (self.cname(True),
+                        % (self.name,
                            str(ndx),
                            type(err).__name__,
                            err))
@@ -374,9 +374,8 @@ class Objective(ActiveIndexedComponent):
              ("Active", self.active)
              ],
             iteritems(self._data),
-            ( "Key","Active","Sense","Expression"),
-            lambda k, v: [ k,
-                           v.active,
+            ( "Active","Sense","Expression"),
+            lambda k, v: [ v.active,
                            ("minimize" if (v.sense == minimize) else "maximize"),
                            v.expr
                            ]
@@ -389,7 +388,7 @@ class Objective(ActiveIndexedComponent):
         tab = "    "
         if ostream is None:
             ostream = sys.stdout
-        ostream.write(prefix+self.cname()+" : ")
+        ostream.write(prefix+self.local_name+" : ")
         ostream.write(", ".join("%s=%s" % (k,v) for k,v in [
                     ("Size", len(self)),
                     ("Index", self._index \
@@ -400,8 +399,8 @@ class Objective(ActiveIndexedComponent):
         ostream.write("\n")
         tabular_writer( ostream, prefix+tab,
                         ((k,v) for k,v in iteritems(self._data) if v.active),
-                        ( "Key","Active","Value" ),
-                        lambda k, v: [ k, v.active, value(v), ] )
+                        ( "Active","Value" ),
+                        lambda k, v: [ v.active, value(v), ] )
 
     #
     # Checks flags like Objective.Skip, etc. before
@@ -437,7 +436,7 @@ class Objective(ActiveIndexedComponent):
                 "object or numeric value. Please modify your rule "
                 "to return Objective.Skip instead of None."
                 "\n\nError thrown for Objective '%s'"
-                % (self._data[index].cname(True)))
+                % (self._data[index].name))
 
         #
         # Ignore an 'empty' objective
@@ -488,13 +487,13 @@ class SimpleObjective(_GeneralObjectiveData, Objective):
                     "Accessing the expression of SimpleObjective "
                     "'%s' before the Objective has been assigned "
                     "a sense or expression. There is currently "
-                    "nothing to access." % (self.cname(True)))
+                    "nothing to access." % (self.name))
             return _GeneralObjectiveData.expr.fget(self)
         raise ValueError(
             "Accessing the expression of objective '%s' "
             "before the Objective has been constructed (there "
             "is currently no value to return)."
-            % (self.cname(True)))
+            % (self.name))
     @expr.setter
     def expr(self, expr):
         """Set the expression of this objective."""
@@ -523,13 +522,13 @@ class SimpleObjective(_GeneralObjectiveData, Objective):
                     "Accessing the sense of SimpleObjective "
                     "'%s' before the Objective has been assigned "
                     "a sense or expression. There is currently "
-                    "nothing to access." % (self.cname(True)))
+                    "nothing to access." % (self.name))
             return _GeneralObjectiveData.sense.fget(self)
         raise ValueError(
             "Accessing the sense of objective '%s' "
             "before the Objective has been constructed (there "
             "is currently no value to return)."
-            % (self.cname(True)))
+            % (self.name))
     @sense.setter
     def sense(self, sense):
         """Set the sense (direction) of this objective."""
@@ -556,7 +555,7 @@ class SimpleObjective(_GeneralObjectiveData, Objective):
             "Setting the value of objective '%s' "
             "before the Objective has been constructed (there "
             "is currently no object to set)."
-            % (self.cname(True)))
+            % (self.name))
 
     def set_sense(self, sense):
         """Set the sense (direction) of this objective."""
@@ -568,7 +567,7 @@ class SimpleObjective(_GeneralObjectiveData, Objective):
             "Setting the sense of objective '%s' "
             "before the Objective has been constructed (there "
             "is currently no object to set)."
-            % (self.cname(True)))
+            % (self.name))
 
     #
     # Leaving this method for backward compatibility reasons.
@@ -580,7 +579,7 @@ class SimpleObjective(_GeneralObjectiveData, Objective):
             raise ValueError(
                 "SimpleObjective object '%s' does not accept "
                 "index values other than None. Invalid value: %s"
-                % (self.cname(True), index))
+                % (self.name, index))
         self.set_value(expr)
         return self
 
@@ -626,7 +625,7 @@ class ObjectiveList(IndexedObjective):
             __debug__ and logger.isEnabledFor(logging.DEBUG)
         if generate_debug_messages:
             logger.debug(
-                "Constructing objective %s" % (self.cname(True)))
+                "Constructing objective %s" % (self.name))
 
         if self._constructed:
             return
