@@ -118,6 +118,10 @@ class _VarData(ComponentData, NumericValue):
         """Returns False because this is not a constant in an expression."""
         return False
 
+    def _potentially_variable(self):
+        """Returns True because this is a variable."""
+        return True
+
     def _polynomial_degree(self, result):
         """
         If the variable is fixed, it represents a constant
@@ -429,7 +433,7 @@ class Var(IndexedComponent):
     def __new__(cls, *args, **kwds):
         if cls != Var:
             return super(Var, cls).__new__(cls)
-        if args == ():
+        if args == () or (type(args[0]) == set and args[0] == UnindexedComponent_set and len(args)==1):
             return SimpleVar.__new__(SimpleVar)
         else:
             return IndexedVar.__new__(IndexedVar)
@@ -529,7 +533,7 @@ class Var(IndexedComponent):
                 vardata = self.add(ndx)
             else:
                 msg = "Cannot set the value of a simple variable '%s' with index '%s'"
-                raise KeyError(msg % ( self.cname(True), str(ndx) ))
+                raise KeyError(msg % (self.name, str(ndx)))
         #
         # Set the value
         #
@@ -540,7 +544,7 @@ class Var(IndexedComponent):
 
         if __debug__ and logger.isEnabledFor(logging.DEBUG):   #pragma:nocover
             try:
-                name = str(self.cname(True))
+                name = str(self.name)
             except:
                 # Some Var components don't have a name yet, so just use the type
                 name = type(self)
@@ -697,20 +701,18 @@ class Var(IndexedComponent):
         return ( [("Size", len(self)),
                   ("Index", self._index \
                        if self._index != UnindexedComponent_set else None),
-                  ("Domain", None if self._domain_init_value is None else self._domain_init_value.name),
                   ],
                  iteritems(self._data),
-                 ( "Key","Lower","Value","Upper","Fixed","Stale" ),
-                 lambda k, v: [ k,
-                                value(v.lb),
+                 ( "Lower","Value","Upper","Fixed","Stale","Domain"),
+                 lambda k, v: [ value(v.lb),
                                 v.value,
                                 value(v.ub),
                                 v.fixed,
                                 v.stale,
+                                v.domain
                                 ]
                  )
 
-
 class SimpleVar(_GeneralVarData, Var):
     """"A single variable."""
 
@@ -746,7 +748,7 @@ class SimpleVar(_GeneralVarData, Var):
             "Accessing the value of variable '%s' "
             "before the Var has been constructed (there "
             "is currently no value to return)."
-            % (self.cname(True)))
+            % (self.name))
     @value.setter
     def value(self, val):
         """Set the value for this variable."""
@@ -756,7 +758,7 @@ class SimpleVar(_GeneralVarData, Var):
             "Setting the value of variable '%s' "
             "before the Var has been constructed (there "
             "is currently nothing to set."
-            % (self.cname(True)))
+            % (self.name))
 
     @property
     def domain(self):
@@ -770,7 +772,7 @@ class SimpleVar(_GeneralVarData, Var):
         #    "Accessing the domain of variable '%s' "
         #    "before the Var has been constructed (there "
         #    "is currently no domain to return)."
-        #    % (self.cname(True)))
+        #    % (self.name))
     @domain.setter
     def domain(self, domain):
         """Set the domain for this variable."""
@@ -780,7 +782,7 @@ class SimpleVar(_GeneralVarData, Var):
             "Setting the domain of variable '%s' "
             "before the Var has been constructed (there "
             "is currently nothing to set."
-            % (self.cname(True)))
+            % (self.name))
 
     @property
     def lb(self):
@@ -791,7 +793,7 @@ class SimpleVar(_GeneralVarData, Var):
             "Accessing the lower bound of variable '%s' "
             "before the Var has been constructed (there "
             "is currently nothing to return)."
-            % (self.cname(True)))
+            % (self.name))
     @lb.setter
     def lb(self, lb):
         raise AttributeError("Assignment not allowed. Use the setlb method")
@@ -805,7 +807,7 @@ class SimpleVar(_GeneralVarData, Var):
             "Accessing the upper bound of variable '%s' "
             "before the Var has been constructed (there "
             "is currently nothing to return)."
-            % (self.cname(True)))
+            % (self.name))
     @ub.setter
     def ub(self, ub):
         raise AttributeError("Assignment not allowed. Use the setub method")
@@ -821,7 +823,7 @@ class SimpleVar(_GeneralVarData, Var):
             "Setting the lower bound of variable '%s' "
             "before the Var has been constructed (there "
             "is currently nothing to set)."
-            % (self.cname(True)))
+            % (self.name))
 
     def setub(self, val):
         """
@@ -834,7 +836,7 @@ class SimpleVar(_GeneralVarData, Var):
             "Setting the upper bound of variable '%s' "
             "before the Var has been constructed (there "
             "is currently nothing to set)."
-            % (self.cname(True)))
+            % (self.name))
 
     def fix(self, *val):
         """
@@ -847,7 +849,7 @@ class SimpleVar(_GeneralVarData, Var):
             "Fixing variable '%s' "
             "before the Var has been constructed (there "
             "is currently nothing to set)."
-            % (self.cname(True)))
+            % (self.name))
 
     def unfix(self):
         """Sets the fixed indicator to False."""
@@ -857,7 +859,7 @@ class SimpleVar(_GeneralVarData, Var):
             "Freeing variable '%s' "
             "before the Var has been constructed (there "
             "is currently nothing to set)."
-            % (self.cname(True)))
+            % (self.name))
 
     free=unfix
 
@@ -913,7 +915,7 @@ class VarList(IndexedVar):
     def construct(self, data=None):
         """Construct this component."""
         if __debug__ and logger.isEnabledFor(logging.DEBUG):
-            logger.debug("Constructing variable list %s",self.cname(True))
+            logger.debug("Constructing variable list %s", self.name)
         IndexedVar.construct(self, data)
 
     def add(self):
