@@ -351,6 +351,25 @@ class TestConstraintCreation(unittest.TestCase):
         model.c = Constraint(rule=rule)
         self.assertRaises(ValueError, model.create_instance)
 
+    def test_nondata_bounds(self):
+        model = ConcreteModel()
+        model.c = Constraint()
+        model.e1 = Expression()
+        model.e2 = Expression()
+        model.e3 = Expression()
+        with self.assertRaises(ValueError):
+            model.c.set_value(model.e1 <= model.e2 <= model.e3)
+        model.e1.expr = 1.0
+        model.e2.expr = 1.0
+        model.e3.expr = 1.0
+        with self.assertRaises(ValueError):
+            model.c.set_value(model.e1 <= model.e2 <= model.e3)
+        model.p1 = Param(mutable=True)
+        model.p2 = Param(mutable=True)
+        model.c.set_value(model.p1 <= model.e1 <= model.p2)
+        model.e1.expr = None
+        model.c.set_value(model.p1 <= model.e1 <= model.p2)
+
     # make sure we can use a mutable param that
     # has not been given a value in the upper bound
     # of an inequality constraint
@@ -1138,7 +1157,7 @@ class MiscConTests(unittest.TestCase):
 
     def test_constructor(self):
         a = Constraint(name="b")
-        self.assertEqual(a.name,"b")
+        self.assertEqual(a.local_name, "b")
         try:
             a = Constraint(foo="bar")
             self.fail("Can't specify an unexpected constructor option")
@@ -1312,8 +1331,8 @@ class MiscConTests(unittest.TestCase):
             pass
         m.c = Constraint()
         self.assertRaisesRegexp(
-            TypeError, "contains non-constant terms \(variables\) "
-            "appearing in a Boolean context", m.c.set_value, a)
+            TypeError, "Relational expression used in an unexpected "
+            "Boolean context.", m.c.set_value, a)
 
     def test_tuple_constraint_create(self):
         def rule1(model):
@@ -1493,5 +1512,13 @@ class MiscConTests(unittest.TestCase):
             pass
         #
 
+    def test_abstract_index(self):
+        model = AbstractModel()
+        model.A = Set()
+        model.B = Set()
+        model.C = model.A | model.B
+        model.x = Constraint(model.C)
+
+
 if __name__ == "__main__":
     unittest.main()
