@@ -19,21 +19,21 @@ from six import iterkeys, itervalues
 logger = logging.getLogger('pyomo.core')
 
 def generate_finite_elements(ds,nfe):
-    """ 
+    """
     This function first checks to see if the number of finite elements
     in the differential set is equal to nfe. If the number of finite
     elements is less than nfe, additional points will be generated. If
-    the number of finite elements is greater than or equal to nfe the 
+    the number of finite elements is greater than or equal to nfe the
     differential set will not be modified
     """
     if (len(ds)-1) >= nfe:
         # In this case the differentialset already contains the
         # desired number or more than the desired number of finite
         # elements so no additional points are needed.
-        return     
+        return
     elif len(ds) == 2:
         # If only bounds have been specified on the differentialset we
-        # generate the desired number of finite elements by 
+        # generate the desired number of finite elements by
         # spreading them evenly over the interval
         step = (max(ds)-min(ds))/float(nfe)
         tmp = min(ds)+step
@@ -46,11 +46,11 @@ def generate_finite_elements(ds,nfe):
         return
     else:
         # This is the case where some points have been specified
-        # inside of the bounds however the desired number of finite 
+        # inside of the bounds however the desired number of finite
         # elements has not been met. We first look at the step sizes
         # between the existing points. Then an additional point
         # is placed at the midpoint of the largest step. This
-        # process is repeated until we have achieved the desired 
+        # process is repeated until we have achieved the desired
         # number of finite elements. If there are multiple "largest steps"
         # the point will be placed at the first occurance of the
         # largest step
@@ -72,7 +72,7 @@ def _add_point(ds):
         if (sortds[i]-sortds[i-1])>maxstep:
             maxstep = sortds[i]-sortds[i-1]
             maxloc = i-1
-            
+
     ds.add(round((sortds[maxloc]+maxstep/2.0),6))
 
 def generate_colloc_points(ds,tau):
@@ -99,14 +99,10 @@ def update_contset_indexed_component(comp):
     that has changed
     """
     # FIXME: This implementation is a hack until Var and Constraint get
-    # moved over to Indexed_Component. The update methods below are 
+    # moved over to Indexed_Component. The update methods below are
     # roughly what the '_default' method in Var and Constraint should
     # do when they get reimplemented.
 
-    # This implementation also assumes that only Var and Constraint components
-    # will be explicitly indexed by a ContinuousSet and thus only checks for 
-    # these two components. 
-
     # Additionally, this implemenation will *NOT* check for or update
     # components which use a ContinuousSet implicitly. ex) an
     # objective function which iterates through a ContinuousSet and
@@ -117,7 +113,7 @@ def update_contset_indexed_component(comp):
     if comp.type() is Suffix:
         return
     if comp.dim() == 1:
-        if comp._index.type() == ContinuousSet: 
+        if comp._index.type() == ContinuousSet:
             if comp._index.get_changed():
                 if isinstance(comp, Var):
                     _update_var(comp)
@@ -126,10 +122,7 @@ def update_contset_indexed_component(comp):
                 elif comp.type() == Expression:
                     _update_expression(comp)
     elif comp.dim() > 1:
-        if isinstance(comp,IndexedComponent):
-            indexset = comp._implicit_subsets
-        else:
-            indexset = comp._index_set
+        indexset = comp._implicit_subsets
 
         for s in indexset:
             if s.type() == ContinuousSet and s.get_changed():
@@ -139,11 +132,11 @@ def update_contset_indexed_component(comp):
                     _update_constraint(comp)
                 elif comp.type() == Expression:
                     _update_expression(comp)
-                                  
+
 def _update_var(v):
     """
-    This method will construct any additional indices in a variable 
-    resulting from the discretization of ContinuousSet 
+    This method will construct any additional indices in a variable
+    resulting from the discretization of ContinuousSet
     """
 
     # Note: This is not required it is handled by the _default method on
@@ -167,11 +160,11 @@ def _update_constraint(con):
             # Code taken from the construct() method of Constraint
             con.add(i,apply_indexed_rule(con,_rule,_parent,i))
 
-def _update_expression(expre): 
-    """ 
-    This method will construct any additional indices in a expression 
-    resulting from the discretization 
-    """ 
+def _update_expression(expre):
+    """
+    This method will construct any additional indices in a expression
+    resulting from the discretization
+    """
     _rule=expre._init_rule
     _parent=expre._parent()
     for i in expre.index_set():
@@ -181,7 +174,7 @@ def _update_expression(expre):
 
 def create_access_function(var):
     """
-    This method returns a function that returns a component by calling 
+    This method returns a function that returns a component by calling
     it rather than indexing it
     """
     def _fun(*args):
@@ -190,10 +183,10 @@ def create_access_function(var):
 
 def create_partial_expression(scheme,expr,ind,loc):
     """
-    This method returns a function which applies a discretization scheme 
+    This method returns a function which applies a discretization scheme
     to an expression along a particular indexind set. This is admittedly a
-    convoluted looking implementation. The idea is that we only apply a 
-    discretization scheme to one indexing set at a time but we also want 
+    convoluted looking implementation. The idea is that we only apply a
+    discretization scheme to one indexing set at a time but we also want
     the function to be expanded over any other indexing sets.
     """
     def _fun(*args):
@@ -203,10 +196,10 @@ def create_partial_expression(scheme,expr,ind,loc):
 def add_discretization_equations(block,d):
     """
     Adds the discretization equations for DerivativeVar d to the Block block.
-    Because certain indices will be valid for some discretization schemes and 
+    Because certain indices will be valid for some discretization schemes and
     not others, we skip any constraints which raise an IndexError.
     """
-        
+
     def _disc_eq(m,*args):
         try:
             return d[args] == d._expr(*args)
@@ -214,9 +207,9 @@ def add_discretization_equations(block,d):
             return Constraint.Skip
 
     if d.dim() == 1:
-        block.add_component(d.name+'_disc_eq',Constraint(d._index,rule=_disc_eq))
+        block.add_component(d.local_name+'_disc_eq',Constraint(d._index,rule=_disc_eq))
     else:
-        block.add_component(d.name+'_disc_eq',Constraint(*d._implicit_subsets,rule=_disc_eq))
+        block.add_component(d.local_name+'_disc_eq',Constraint(*d._implicit_subsets,rule=_disc_eq))
 
 def add_continuity_equations(block,d,i,loc):
     """
@@ -224,10 +217,10 @@ def add_continuity_equations(block,d,i,loc):
     does not have a root at the finite element boundary
     """
     svar = d.get_state_var()
-    nme = svar.name+'_'+i.name+'_cont_eq'
+    nme = svar.local_name+'_'+i.local_name+'_cont_eq'
     if block.find_component(nme) is not None:
         return
-    
+
     def _cont_exp(v,s):
         ncp = s.get_discretization_info()['ncp']
         afinal = s.get_discretization_info()['afinal']
@@ -264,76 +257,74 @@ def block_fully_discretized(b):
             return False
     return True
 
-def get_index_information(var,ds): 
-    """ 
-    This method will find the index location of the set ds in the var, return 
-    a list of the non_ds indices and return a function that can be used to 
-    access specific indices in var indexed by a ContinuousSet by specifying the 
-    finite element and collocation point. Users of this method should have 
-    already confirmed that ds is an indexing set of var and that it's a ContinuousSet 
-    """ 
+def get_index_information(var,ds):
+    """
+    This method will find the index location of the set ds in the var, return
+    a list of the non_ds indices and return a function that can be used to
+    access specific indices in var indexed by a ContinuousSet by specifying the
+    finite element and collocation point. Users of this method should have
+    already confirmed that ds is an indexing set of var and that it's a ContinuousSet
+    """
 
-    # Find index order of ContinuousSet in the variable 
-    indargs=[] 
-    dsindex=0 
-    tmpds2=None 
+    # Find index order of ContinuousSet in the variable
+    indargs=[]
+    dsindex=0
+    tmpds2=None
 
-    if var.dim() != 1: 
-        # If/when Var is changed to SparseIndexedComponent, the _index_set 
-        # attribute below may need to be changed 
-        indCount = 0 
-        for index in var._index_set: 
-            if isinstance(index,ContinuousSet): 
-                if index ==ds: 
-                    dsindex = indCount 
-                else: 
-                    indargs.append(index)  # If var is indexed by multiple ContinuousSets treat 
-                                           # other ContinuousSets like a normal indexing set 
-                indCount += 1     # A ContinuousSet must be one dimensional 
-            else: 
-                indargs.append(index) 
-                indCount += index.dimen 
+    if var.dim() != 1:
+        indCount = 0
+        for index in var._implicit_subsets:
+            if isinstance(index,ContinuousSet):
+                if index ==ds:
+                    dsindex = indCount
+                else:
+                    indargs.append(index)  # If var is indexed by multiple ContinuousSets treat
+                                           # other ContinuousSets like a normal indexing set
+                indCount += 1     # A ContinuousSet must be one dimensional
+            else:
+                indargs.append(index)
+                indCount += index.dimen
 
-    if indargs == []: 
-        non_ds = (None,) 
-    elif len(indargs)>1: 
-        non_ds = tuple(a for a in indargs) 
-    else: 
-        non_ds = (indargs[0],) 
- 
-    if None in non_ds: 
-        tmpidx = (None,) 
-    elif len(non_ds)==1: 
-        tmpidx = non_ds[0] 
-    else: 
-        tmpidx = non_ds[0].cross(*non_ds[1:]) 
+    if indargs == []:
+        non_ds = (None,)
+    elif len(indargs)>1:
+        non_ds = tuple(a for a in indargs)
+    else:
+        non_ds = (indargs[0],)
 
-    # Lambda function used to generate the desired index 
-    # more concisely 
-    idx = lambda n,i,k: _get_idx(dsindex,ds,n,i,k) 
+    if None in non_ds:
+        tmpidx = (None,)
+    elif len(non_ds)==1:
+        tmpidx = non_ds[0]
+    else:
+        tmpidx = non_ds[0].cross(*non_ds[1:])
 
-    info = {} 
-    info['non_ds']=tmpidx 
-    info['index function'] = idx 
-    return info 
+    # Lambda function used to generate the desired index
+    # more concisely
+    idx = lambda n,i,k: _get_idx(dsindex,ds,n,i,k)
+
+    info = {}
+    info['non_ds']=tmpidx
+    info['index function'] = idx
+    return info
 
 
-def _get_idx(l,ds,n,i,k): 
-    """ 
-    This function returns the appropriate index for a variable 
-    indexed by a differential set. It's needed because the collocation 
-    constraints are indexed by finite element and collocation point 
-    however a ContinuousSet contains a list of all the discretization 
-    points and is not separated into finite elements and collocation 
-    points. 
-    """ 
-    t = sorted(ds) 
-    tmp = t.index(ds._fe[i]) 
-    tik = t[tmp+k] 
-    if n is None: 
-        return tik 
-    else: 
-        tmpn=n 
-        if not isinstance(n,tuple): 
-            tmpn = (n,) 
-    return tmpn[0:l]+(tik,)+tmpn[l:]   
+def _get_idx(l,ds,n,i,k):
+    """
+    This function returns the appropriate index for a variable
+    indexed by a differential set. It's needed because the collocation
+    constraints are indexed by finite element and collocation point
+    however a ContinuousSet contains a list of all the discretization
+    points and is not separated into finite elements and collocation
+    points.
+    """
+    t = sorted(ds)
+    tmp = t.index(ds._fe[i])
+    tik = t[tmp+k]
+    if n is None:
+        return tik
+    else:
+        tmpn=n
+        if not isinstance(n,tuple):
+            tmpn = (n,)
+    return tmpn[0:l]+(tik,)+tmpn[l:]
