@@ -25,7 +25,7 @@ from pyomo.dae.misc import block_fully_discretized
 from pyomo.dae.misc import get_index_information
 
 # If the user has numpy then the collocation points and the a matrix for
-# the Runge-Kutta basis formulation will be calculated as needed. 
+# the Runge-Kutta basis formulation will be calculated as needed.
 # If the user does not have numpy then these values will be read from a
 # stored dictionary for up to 10 collocation points.
 try:
@@ -239,7 +239,7 @@ class Collocation_Discretization_Transformation(Transformation):
         instance = instance.clone()
         instance.construct()
         return instance
-        
+
     def _get_radau_constants(self,currentds):
         """
         This function sets the radau collocation points and a values depending
@@ -297,7 +297,7 @@ class Collocation_Discretization_Transformation(Transformation):
             self._adot[currentds] = adot
             self._adotdot[currentds] = adotdot
             self._afinal[currentds] = afinal
-    
+
     def _get_hermite_constants(self,currentds):
         # TODO: finish this
         raise DAE_Error("Not Implemented")
@@ -307,16 +307,16 @@ class Collocation_Discretization_Transformation(Transformation):
         Applies specified collocation transformation to a modeling instance
 
         Keyword Arguments:
-        nfe           The desired number of finite element points to be 
+        nfe           The desired number of finite element points to be
                       included in the discretization.
-        ncp           The desired number of collocation points over each 
+        ncp           The desired number of collocation points over each
                       finite element.
-        wrt           Indicates which ContinuousSet the transformation 
+        wrt           Indicates which ContinuousSet the transformation
                       should be applied to. If this keyword argument is not
                       specified then the same scheme will be applied to all
                       ContinuousSets.
-        scheme        Indicates which finite difference method to apply. 
-                      Options are LAGRANGE-RADAU, LAGRANGE-LEGENDRE, or 
+        scheme        Indicates which finite difference method to apply.
+                      Options are LAGRANGE-RADAU, LAGRANGE-LEGENDRE, or
                       HERMITE-CUBIC. The default scheme is Lagrange polynomials
                       with Radau roots.
         """
@@ -324,7 +324,7 @@ class Collocation_Discretization_Transformation(Transformation):
         options = kwds.pop('options', {})
 
         tmpnfe = kwds.pop('nfe',10)
-        tmpncp = kwds.pop('ncp',3)        
+        tmpncp = kwds.pop('ncp',3)
         tmpds = kwds.pop('wrt',None)
         tmpscheme = kwds.pop('scheme','LAGRANGE-RADAU')
         self._scheme_name = tmpscheme.upper()
@@ -335,13 +335,13 @@ class Collocation_Discretization_Transformation(Transformation):
                      "must be a differential set")
             elif 'scheme' in tmpds.get_discretization_info():
                 raise ValueError("The discretization scheme '%s' has already been applied "\
-                     "to the ContinuousSet '%s'"%s(tmpds.get_discretization_info()['scheme'],tmpds.cname(True)))
-            
+                     "to the ContinuousSet '%s'"%s(tmpds.get_discretization_info()['scheme'],tmpds.name))
+
         if tmpnfe <=0:
             raise ValueError("The number of finite elements must be at least 1")
         if tmpncp <= 0:
             raise ValueError("The number of collocation points must be at least 1")
-        
+
         if None in self._nfe:
             raise ValueError("A general discretization scheme has already been applied to "\
                     "to every differential set in the model. If you would like to specify a "\
@@ -349,23 +349,23 @@ class Collocation_Discretization_Transformation(Transformation):
                     "each differential set individually. If you would like to apply a different "\
                     "discretization scheme to all differential sets you must declare a new Collocation"\
                     "_Discretization object")
-        
+
         if len(self._nfe) == 0 and tmpds is None:
             # Same discretization on all differentialsets
             self._nfe[None] = tmpnfe
             self._ncp[None] = tmpncp
             currentds = None
         else :
-            self._nfe[tmpds.name]=tmpnfe
-            self._ncp[tmpds.name]=tmpncp
-            currentds = tmpds.cname(True)
+            self._nfe[tmpds.local_name]=tmpnfe
+            self._ncp[tmpds.local_name]=tmpncp
+            currentds = tmpds.name
 
         self._scheme = self.all_schemes.get(self._scheme_name,None)
         if self._scheme is None:
             raise ValueError("Unknown collocation scheme '%s' specified using the "\
                      "'scheme' keyword. Valid schemes are 'LAGRANGE-RADAU', 'LAGRANGE-LEGENDRE'"\
                      ", and 'HERMITE-CUBIC'" %(tmpscheme))
-              
+
         if self._scheme_name == 'LAGRANGE-RADAU':
             self._get_radau_constants(currentds)
         elif self._scheme_name == 'LAGRANGE-LEGENDRE':
@@ -377,38 +377,38 @@ class Collocation_Discretization_Transformation(Transformation):
         return instance
 
     def _transformBlock(self, block, currentds):
-        
+
         self._fe = {}
         for ds in itervalues(block.component_map(ContinuousSet)):
-            if currentds is None or currentds == ds.cname(True):
+            if currentds is None or currentds == ds.name:
                 generate_finite_elements(ds,self._nfe[currentds])
                 if not ds.get_changed():
                     if len(ds)-1 > self._nfe[currentds]:
                         print("***WARNING: More finite elements were found in differentialset "\
                             "'%s' than the number of finite elements specified in apply. "\
-                              "The larger number of finite elements will be used." % (ds.cname(True),))
-                
-                self._nfe[ds.cname(True)]=len(ds)-1
-                self._fe[ds.cname(True)]=sorted(ds)
+                              "The larger number of finite elements will be used." % (ds.name,))
+
+                self._nfe[ds.name]=len(ds)-1
+                self._fe[ds.name]=sorted(ds)
                 generate_colloc_points(ds,self._tau[currentds])
                 # Adding discretization information to the differentialset object itself
                 # so that it can be accessed outside of the discretization object
                 disc_info = ds.get_discretization_info()
-                disc_info['nfe']=self._nfe[ds.cname(True)]
+                disc_info['nfe']=self._nfe[ds.name]
                 disc_info['ncp']=self._ncp[currentds]
                 disc_info['tau_points']=self._tau[currentds]
                 disc_info['adot'] = self._adot[currentds]
                 disc_info['adotdot'] = self._adotdot[currentds]
                 disc_info['afinal'] = self._afinal[currentds]
-                disc_info['scheme'] = self._scheme_name          
-        
+                disc_info['scheme'] = self._scheme_name
+
         for c in itervalues(block.component_map()):
             update_contset_indexed_component(c)
 
         for d in itervalues(block.component_map(DerivativeVar)):
             dsets = d.get_continuousset_list()
             for i in set(dsets):
-                if currentds is None or i.cname(True) == currentds:
+                if currentds is None or i.name == currentds:
                     oldexpr = d.get_derivative_expression()
                     loc = d.get_state_var()._contset[i]
                     count = dsets.count(i)
@@ -416,22 +416,22 @@ class Collocation_Discretization_Transformation(Transformation):
                         raise DAE_Error(
                             "Error discretizing '%s' with respect to '%s'. Current implementation "\
                             "only allows for taking the first or second derivative with respect to "\
-                            "a particular ContinuousSet" %s(d.cname(True),i.cname(True)))
+                            "a particular ContinuousSet" %s(d.name,i.name))
                     scheme = self._scheme[count-1]
                     # print("%s %s" % (i.name, scheme.__name__))
                     newexpr = create_partial_expression(scheme,oldexpr,i,loc)
                     d.set_derivative_expression(newexpr)
                     if self._scheme_name == 'LAGRANGE-LEGENDRE':
                         add_continuity_equations(block,d,i,loc)
-      
+
             # Reclassify DerivativeVar if all indexing ContinuousSets have been discretized
             if d.is_fully_discretized():
                 add_discretization_equations(block,d)
                 block.reclassify_component_type(d,Var)
 
-        # Reclassify Integrals if all ContinuousSets have been discretized       
+        # Reclassify Integrals if all ContinuousSets have been discretized
         if block_fully_discretized(block):
-            
+
             if block.contains_component(Integral):
                 for i in itervalues(block.component_map(Integral)):
                     i.reconstruct()
@@ -444,13 +444,13 @@ class Collocation_Discretization_Transformation(Transformation):
     def _get_idx(self,l,t,n,i,k):
         """
         This function returns the appropriate index for the differential
-        and the derivative variables. It's needed because the collocation 
+        and the derivative variables. It's needed because the collocation
         constraints are indexed by finite element and collocation point
         however a differentialset contains a list of all the discretization
         points and is not separated into finite elements and collocation
         points.
         """
-        
+
         tmp = t.index(t._fe[i])
         tik = t[tmp+k]
         if n is None:
@@ -459,7 +459,7 @@ class Collocation_Discretization_Transformation(Transformation):
             tmpn=n
             if not isinstance(n,tuple):
                 tmpn = (n,)
-            return tmpn[0:l]+(tik,)+tmpn[l:]   
+            return tmpn[0:l]+(tik,)+tmpn[l:]
 
     def reduce_collocation_points(self, instance, var=None, ncp=None, contset=None):
         """
@@ -472,32 +472,32 @@ class Collocation_Discretization_Transformation(Transformation):
         if contset.type() is not ContinuousSet:
             raise TypeError("The component specified using the 'contset' keyword "\
                 "must be a differential set")
-        ds = instance.find_component(contset.cname(True))
+        ds = instance.find_component(contset.name)
         if ds is None:
             raise ValueError("ContinuousSet '%s' is not a valid component of the discretized "\
-                "model instance" %(contset.cname(True)))
+                "model instance" %(contset.name))
 
         if len(self._ncp) == 0:
             raise RuntimeError("This method should only be called after using the apply() method "\
                 "to discretize the model")
         elif None in self._ncp:
             tot_ncp = self._ncp[None]
-        elif ds.cname(True) in self._ncp:
-            tot_ncp = self._ncp[ds.cname(True)]
+        elif ds.name in self._ncp:
+            tot_ncp = self._ncp[ds.name]
         else:
             raise ValueError("ContinuousSet '%s' has not been discretized yet, please call "\
                 "the apply() method with this ContinuousSet to discretize it before calling "\
-                "this method" %s(ds.cname(True)))
+                "this method" %s(ds.name))
 
         if var is None:
             raise TypeError("A variable must be specified")
         if var.type() is not Var:
             raise TypeError("The component specified using the 'var' keyword "\
                 "must be a variable")
-        tmpvar = instance.find_component(var.cname(True))
+        tmpvar = instance.find_component(var.name)
         if tmpvar is None:
             raise ValueError("Variable '%s' is not a valid component of the discretized "\
-                "model instance" %(var.cname(True)))
+                "model instance" %(var.name))
 
         var = tmpvar
 
@@ -517,23 +517,23 @@ class Collocation_Discretization_Transformation(Transformation):
         if var.dim() == 1:
             if ds not in var._index:
                 raise IndexError("ContinuousSet '%s' is not an indexing set of the variable '%s'"\
-                    % (ds.name,var.cname(True)))
+                    % (ds.name, var.name))
         elif ds not in var._index_set:
             raise IndexError("ContinuousSet '%s' is not an indexing set of the variable '%s'"\
-                % (ds.name,var.name))
+                             % (ds.name, var.name))
 
-        if var.cname(True) in self._reduced_cp:
-            temp = self._reduced_cp[var.cname(True)]
-            if ds.cname(True) in temp:
+        if var.name in self._reduced_cp:
+            temp = self._reduced_cp[var.name]
+            if ds.name in temp:
                 raise RuntimeError("Variable '%s' has already been constrained to a reduced "\
                     "number of collocation points over ContinuousSet '%s'.")
             else:
-                temp[ds.name]=ncp
+                temp[ds.local_name]=ncp
         else:
-            self._reduced_cp[var.name] = {ds.name:ncp}                
-        
-        list_name = var.name+"_interpolation_constraints"
-        
+            self._reduced_cp[var.local_name] = {ds.local_name: ncp}
+
+        list_name = var.local_name+"_interpolation_constraints"
+
         instance.add_component(list_name,ConstraintList())
         conlist = instance.find_component(list_name)
 
@@ -563,7 +563,7 @@ class Collocation_Discretization_Transformation(Transformation):
         return instance
 
     def _interpolation_coeffs(self,ti,tfit):
-  
+
         for i in tfit:
             l=1
             for j in tfit:
