@@ -13,6 +13,11 @@
 
 __all__ = ['ProblemWriter_nl']
 
+try:
+    basestring
+except:
+    basestring = str
+
 import itertools
 import logging
 import operator
@@ -26,7 +31,7 @@ import pyomo.util.plugin
 from pyomo.opt import ProblemFormat
 from pyomo.opt.base import *
 from pyomo.core.base import *
-from pyomo.core.base import expr, external, SymbolMap, Block
+from pyomo.core.base import expr, SymbolMap, Block
 import pyomo.core.base.expr_common
 from pyomo.core.base.var import Var
 from pyomo.core.base import _ExpressionData, Expression, SortComponents
@@ -90,10 +95,10 @@ del prod_comment
 del div_template
 del div_comment
 
-_op_template[external._ExternalFunctionExpression] = ("f%d %d{C}\n", #function
-                                                      "h%d:%s{C}\n") #string arg
-_op_comment[external._ExternalFunctionExpression] = ("\t#%s", #function
-                                                     "")      #string arg
+_op_template[expr._ExternalFunctionExpression] = ("f%d %d{C}\n", #function
+                                                  "h%d:%s{C}\n") #string arg
+_op_comment[expr._ExternalFunctionExpression] = ("\t#%s", #function
+                                                 "")      #string arg
 
 for opname in _intrinsic_function_operators:
     _op_template[opname] = _intrinsic_function_operators[opname]+"{C}\n"
@@ -214,7 +219,7 @@ class ModelSOS(object):
         else:
             raise ValueError("SOSContraint '%s' has sos type='%s', "
                              "which is not supported by the NL file interface" \
-                                 % (soscondata.cname(True), level))
+                                 % (soscondata.name, level))
 
         for vardata, weight in soscondata.get_items():
             if vardata.fixed:
@@ -222,7 +227,7 @@ class ModelSOS(object):
                     "SOSConstraint '%s' includes a fixed Variable '%s'. "
                     "This is currently not supported. Deactivate this constraint "
                     "in order to proceed"
-                    % (soscondata.cname(True), vardata.cname(True)))
+                    % (soscondata.name, vardata.name))
 
             ID = ampl_var_id[varID_map[id(vardata)]]
             self.sosno.add(ID,self.block_cntr*sign_tag)
@@ -306,7 +311,7 @@ class ProblemWriter_nl(AbstractProblemWriter):
                 "\n\t".join("%s = %s" % (k,v) for k,v in iteritems(io_options)))
 
         if filename is None:
-            filename = model.cname() + ".nl"
+            filename = model.name + ".nl"
 
         # Generate the operator strings templates. The value of
         # symbolic_solver_labels determines whether or not to
@@ -334,7 +339,7 @@ class ProblemWriter_nl(AbstractProblemWriter):
         # passed into _print_nonlinear_terms_NL
         self._symbolic_solver_labels = symbolic_solver_labels
         self._output_fixed_variable_bounds = output_fixed_variable_bounds
-        # Speeds up calling cname on every component when
+        # Speeds up calling name on every component when
         # writing .row and .col files (when symbolic_solver_labels is True)
         self._name_labeler = NameLabeler()
 
@@ -539,19 +544,19 @@ class ProblemWriter_nl(AbstractProblemWriter):
                 OUTPUT.write(self._op_string[expr._NegationExpression])
                 self._print_nonlinear_terms_NL(exp._args[0])
 
-            elif exp_type is external._ExternalFunctionExpression:
+            elif exp_type is expr._ExternalFunctionExpression:
                 fun_str, string_arg_str = \
-                    self._op_string[external._ExternalFunctionExpression]
+                    self._op_string[expr._ExternalFunctionExpression]
                 if not self._symbolic_solver_labels:
                     OUTPUT.write(fun_str
                                  % (self.external_byFcn[exp._fcn._function][1],
                                     len(exp._args)))
                 else:
-                    # Note: exp.cname(True) fails
+                    # Note: exp.name fails
                     OUTPUT.write(fun_str
                                  % (self.external_byFcn[exp._fcn._function][1],
                                     len(exp._args),
-                                    exp.cname()))
+                                    exp.name))
                 for arg in exp._args:
                     if isinstance(arg, basestring):
                         OUTPUT.write(string_arg_str % (len(arg), arg))
@@ -559,14 +564,14 @@ class ProblemWriter_nl(AbstractProblemWriter):
                         self._print_nonlinear_terms_NL(arg)
             elif (exp_type is expr._PowExpression) or \
                  isinstance(exp, expr._IntrinsicFunctionExpression):
-                intr_expr_str = self._op_string.get(exp.cname())
+                intr_expr_str = self._op_string.get(exp.name)
                 if intr_expr_str is not None:
                     OUTPUT.write(intr_expr_str)
                 else:
                     logger.error("Unsupported intrinsic function ({0})",
-                                 exp.cname(True))
+                                 exp.name)
                     raise TypeError("ASL writer does not support '%s' expressions"
-                                    % (exp.cname(True)))
+                                    % (exp.name))
 
                 for child_exp in exp._args:
                     self._print_nonlinear_terms_NL(child_exp)
@@ -661,6 +666,12 @@ class ProblemWriter_nl(AbstractProblemWriter):
         symbol_map = SymbolMap()
 
         name_labeler = self._name_labeler
+        # These will get updated when symbolic_solver_labels
+        # is true. It is critical that nonzero values go in
+        # the header of the NL file if you want ASL to
+        # parse the .row and .col files.
+        max_rowname_len = 0
+        max_colname_len = 0
 
         #
         # Collect statistics
@@ -699,9 +710,9 @@ class ProblemWriter_nl(AbstractProblemWriter):
                     "correctly." %
                     (fcn._function,
                      self.external_byFcn[fcn._function]._library,
-                     self.external_byFcn[fcn._function]._library.cname(True),
+                     self.external_byFcn[fcn._function]._library.name,
                      fcn._library,
-                     fcn.cname(True)))
+                     fcn.name))
             self.external_byFcn[fcn._function] = (fcn, len(self.external_byFcn))
             external_Libs.add(fcn._library)
         if external_Libs:
@@ -753,6 +764,10 @@ class ProblemWriter_nl(AbstractProblemWriter):
                                                                  active=True,
                                                                  sort=sorter,
                                                                  descend_into=False):
+                if symbolic_solver_labels:
+                    objname = name_labeler(active_objective)
+                    if len(objname) > max_rowname_len:
+                        max_rowname_len = len(objname)
 
                 if gen_obj_ampl_repn:
                     ampl_repn = generate_ampl_repn(active_objective.expr)
@@ -787,7 +802,7 @@ class ProblemWriter_nl(AbstractProblemWriter):
             raise ValueError(
                 "The NL writer has detected multiple active objective functions "
                 "on model %s, but currently only handles a single objective."
-                % (model.cname(True)))
+                % (model.name))
         elif n_objs == 1:
             symbol_map.alias(symbol_map.bySymbol["o0"](),"__default_objective__")
 
@@ -830,6 +845,10 @@ class ProblemWriter_nl(AbstractProblemWriter):
                                                                 active=True,
                                                                 sort=sorter,
                                                                 descend_into=False):
+                if symbolic_solver_labels:
+                    conname = name_labeler(constraint_data)
+                    if len(conname) > max_rowname_len:
+                        max_rowname_len = len(conname)
 
                 if gen_con_ampl_repn:
                     ampl_repn = generate_ampl_repn(constraint_data.body)
@@ -975,7 +994,7 @@ class ProblemWriter_nl(AbstractProblemWriter):
                 L = var.lb
                 U = var.ub
                 if L is None or U is None:
-                    raise ValueError("Variable " + str(var.cname(True)) +\
+                    raise ValueError("Variable " + str(var.name) +\
                                      "is binary, but does not have lb and ub set")
                 LinearVarsBool.add(var_ID)
             elif not var.is_continuous():
@@ -1105,8 +1124,12 @@ class ProblemWriter_nl(AbstractProblemWriter):
             colfilename = OUTPUT.name+'.col'
         if symbolic_solver_labels:
             colf = open(colfilename,'w')
+            colfile_line_template = "%s\n"
             for var_ID in full_var_list:
-                colf.write(name_labeler(Vars_dict[var_ID])+'\n')
+                varname = name_labeler(Vars_dict[var_ID])
+                colf.write(colfile_line_template % varname)
+                if len(varname) > max_colname_len:
+                    max_colname_len = len(varname)
             colf.close()
 
         if show_section_timing:
@@ -1118,7 +1141,7 @@ class ProblemWriter_nl(AbstractProblemWriter):
         #
         # LINE 1
         #
-        OUTPUT.write("g3 1 1 0\t# problem {0}\n".format(model.cname()))
+        OUTPUT.write("g3 1 1 0\t# problem {0}\n".format(model.name))
         #
         # LINE 2
         #
@@ -1181,7 +1204,9 @@ class ProblemWriter_nl(AbstractProblemWriter):
         #
         # LINE 9
         #
-        OUTPUT.write(" 0 0\t# max name lengths: constraints, variables\n")
+        OUTPUT.write(" %d %d\t# max name lengths: constraints, variables\n"
+                     % (max_rowname_len, max_colname_len))
+
         #
         # LINE 10
         #
@@ -1359,7 +1384,7 @@ class ProblemWriter_nl(AbstractProblemWriter):
                     logger.warning(
                         "ProblemWriter_nl: Collected multiple values for Suffix %s "
                         "referencing model %s. This is likely a bug."
-                        % (suffix_name, model.cname(True)))
+                        % (suffix_name, model.name))
                 OUTPUT.write(suffix_header_line.format(prob_tag | float_tag,
                                                        len(mod_s_lines),
                                                        suffix_name))
@@ -1496,7 +1521,7 @@ class ProblemWriter_nl(AbstractProblemWriter):
                         "indicative of a preprocessing error. Use the IO-option "
                         "'output_fixed_variable_bounds=True' to suppress this error "
                         "and fix the variable by overwriting its bounds in the NL "
-                        "file." % (var.cname(True), model.cname(True)))
+                        "file." % (var.name, model.name))
                 if var.value is None:
                     raise ValueError("Variable cannot be fixed to a value of None.")
                 L = var.value
